@@ -1,4 +1,4 @@
-/* $Id: irplib_polynomial-test.c,v 1.35 2011-12-14 13:05:01 llundin Exp $
+/* $Id: irplib_polynomial-test.c,v 1.37 2013-01-29 08:43:33 jtaylor Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2004 European Southern Observatory
@@ -15,13 +15,13 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02111-1307  USA
  */
 
 /*
- * $Author: llundin $
- * $Date: 2011-12-14 13:05:01 $
- * $Revision: 1.35 $
+ * $Author: jtaylor $
+ * $Date: 2013-01-29 08:43:33 $
+ * $Revision: 1.37 $
  * $Name: not supported by cvs2svn $
  */
 
@@ -36,12 +36,13 @@
 #include <irplib_polynomial.h>
 #include <math.h>
 #include <float.h>
+#include <stdint.h>
 
 /*-----------------------------------------------------------------------------
                                    Defines
  -----------------------------------------------------------------------------*/
 
-#define MAXDEGREE 6
+#define MAXDEGREE 14
 
 #define irplib_polynomial_test_root_all(A, B, C, D, E)                  \
     irplib_polynomial_test_root_all_macro(A, B, C, D, E, __LINE__)
@@ -90,33 +91,32 @@ static void irplib_polynomial_solve_1d_all_test(void)
     const cpl_size   maxdegree = 4; /* Largest robustly handled degree */
     cpl_size         nreal = 0;
     cpl_size         i;
+    cpl_error_code   code;
+#if MAXDEGREE > 8
+    double           stol, rtol;
+#endif
 
-    cpl_test_eq(irplib_polynomial_solve_1d_all(NULL, xtrue, &nreal),
-                CPL_ERROR_NULL_INPUT);
-    cpl_test_error(CPL_ERROR_NULL_INPUT);
+    code = irplib_polynomial_solve_1d_all(NULL, xtrue, &nreal);
+    cpl_test_eq_error(code, CPL_ERROR_NULL_INPUT);
 
-    cpl_test_eq(irplib_polynomial_solve_1d_all(p1d, NULL, &nreal),
-                CPL_ERROR_NULL_INPUT);
-    cpl_test_error(CPL_ERROR_NULL_INPUT);
+    code = irplib_polynomial_solve_1d_all(p1d, NULL, &nreal);
+    cpl_test_eq_error(code, CPL_ERROR_NULL_INPUT);
 
-    cpl_test_eq(irplib_polynomial_solve_1d_all(p1d, xtrue, NULL),
-                CPL_ERROR_NULL_INPUT);
-    cpl_test_error(CPL_ERROR_NULL_INPUT);
+    code = irplib_polynomial_solve_1d_all(p1d, xtrue, NULL);
+    cpl_test_eq_error(code, CPL_ERROR_NULL_INPUT);
 
-    cpl_test_eq(irplib_polynomial_solve_1d_all(p2d, xtrue, &nreal),
-                CPL_ERROR_INVALID_TYPE);
-    cpl_test_error(CPL_ERROR_INVALID_TYPE);
+    code = irplib_polynomial_solve_1d_all(p2d, xtrue, &nreal);
+    cpl_test_eq_error(code, CPL_ERROR_INVALID_TYPE);
 
-    cpl_test_eq(irplib_polynomial_solve_1d_all(p1d, xtrue, &nreal),
-                CPL_ERROR_DATA_NOT_FOUND);
-    cpl_test_error(CPL_ERROR_DATA_NOT_FOUND);
+    code = irplib_polynomial_solve_1d_all(p1d, xtrue, &nreal);
+    cpl_test_eq_error(code, CPL_ERROR_DATA_NOT_FOUND);
 
     /* Create a 1st degree polynomial, x = 0 */
     i = 1;
-    cpl_test_eq(cpl_polynomial_set_coeff(p1d, &i, 1.0), CPL_ERROR_NONE);
-    cpl_test_eq(irplib_polynomial_solve_1d_all(p1d, xtrue, &nreal),
-                CPL_ERROR_INCOMPATIBLE_INPUT);
-    cpl_test_error(CPL_ERROR_INCOMPATIBLE_INPUT);
+    code = cpl_polynomial_set_coeff(p1d, &i, 1.0);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    code = irplib_polynomial_solve_1d_all(p1d, xtrue, &nreal);
+    cpl_test_eq_error(code, CPL_ERROR_INCOMPATIBLE_INPUT);
 
     cpl_polynomial_delete(p1d);
     cpl_polynomial_delete(p2d);
@@ -202,11 +202,17 @@ static void irplib_polynomial_solve_1d_all_test(void)
                                         DBL_EPSILON, 2.0*DBL_EPSILON);
 
         /* A more extreme case: Same with negative roots */
-        (void)cpl_vector_fill(xtrue, -2.0e-4 * FLT_EPSILON);
+#if defined SIZE_MAX && SIZE_MAX <= 4294967295
+        /* Fails on 32-bit - also w. -0.1 * FLT_EPSILON */
+#else
+        (void)cpl_vector_fill(xtrue, -0.2 * FLT_EPSILON);
+
         (void)cpl_vector_set(xtrue, 0, -1.0);
 
         irplib_polynomial_test_root_all(xtrue, nreal, CPL_MATH_PI,
                                         FLT_EPSILON, 3.0*DBL_EPSILON);
+#endif
+
 
         if (nreal != 3) {
             /* The most extreme case: Same with negative roots */
@@ -253,7 +259,7 @@ static void irplib_polynomial_solve_1d_all_test(void)
 
     cpl_vector_set_size(xtrue, nreal);
 
-    /* -2, epsilon, 1  */
+    /* -2, epsilon, 1.5  */
     (void)cpl_vector_set(xtrue, 0, -2.0);
     (void)cpl_vector_set(xtrue, 1,  2.0 * DBL_EPSILON);
     (void)cpl_vector_set(xtrue, 2,  1.5);
@@ -261,6 +267,13 @@ static void irplib_polynomial_solve_1d_all_test(void)
     irplib_polynomial_test_root_all(xtrue, nreal, 1.0,
                                     4.0*DBL_EPSILON, 30.0*DBL_EPSILON);
 
+    (void)cpl_vector_set(xtrue, 0,  1.0);
+    (void)cpl_vector_set(xtrue, 1,  2.0);
+    (void)cpl_vector_set(xtrue, 2,  1.0);
+
+    irplib_polynomial_test_root_all(xtrue, nreal-2, 1.0,
+                                    4.0*DBL_EPSILON, 30.0*DBL_EPSILON);
+
 #if MAXDEGREE > 3
     nreal = 4;
 
@@ -328,8 +341,8 @@ static void irplib_polynomial_solve_1d_all_test(void)
     i = 4;
     cpl_polynomial_set_coeff(p1d, &i,  1.0);
 
-    cpl_test_eq(irplib_polynomial_solve_1d_all(p1d, xtrue, &nreal),
-                CPL_ERROR_NONE);
+    code = irplib_polynomial_solve_1d_all(p1d, xtrue, &nreal);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
 
     cpl_msg_info(cpl_func, "Computed roots (%" CPL_SIZE_FORMAT " real): ",
                  nreal);
@@ -378,6 +391,26 @@ static void irplib_polynomial_solve_1d_all_test(void)
     irplib_polynomial_test_root_all(xtrue, nreal-4, CPL_MATH_PI,
                                     4.0 * DBL_EPSILON, 600.0 * DBL_EPSILON);
 
+    (void)cpl_vector_set(xtrue, 0, -1.0);
+    (void)cpl_vector_set(xtrue, 1, 10.0);
+    (void)cpl_vector_set(xtrue, 2,  1.0);
+    (void)cpl_vector_set(xtrue, 3, 20.0);
+    (void)cpl_vector_set(xtrue, 4,  1.0);
+
+    irplib_polynomial_test_root_all(xtrue, 1, 1.0,
+                                    DBL_EPSILON, DBL_EPSILON);
+
+    (void)cpl_vector_set(xtrue, 0,   4.0);
+    (void)cpl_vector_set(xtrue, 1, -10.0);
+    (void)cpl_vector_set(xtrue, 2,   4.0);
+    (void)cpl_vector_set(xtrue, 3,  10.0);
+    (void)cpl_vector_set(xtrue, 4,   4.0);
+
+    irplib_polynomial_test_root_all(xtrue, 1, 1.0,
+                                    DBL_EPSILON, DBL_EPSILON);
+    irplib_polynomial_test_root_all(xtrue, 1, -1.0,
+                                    DBL_EPSILON, DBL_EPSILON);
+
 #if MAXDEGREE > 5
     nreal = 6;
 
@@ -395,11 +428,146 @@ static void irplib_polynomial_solve_1d_all_test(void)
                                     240.0 * DBL_EPSILON, 50.0e3 * DBL_EPSILON);
 
     irplib_polynomial_test_root_all(xtrue, nreal-2, CPL_MATH_PI,
-                                    8.0 * DBL_EPSILON, 25.0e3 * DBL_EPSILON);
+                                    10.0 * DBL_EPSILON, 25.0e3 * DBL_EPSILON);
 
     irplib_polynomial_test_root_all(xtrue, nreal-4, CPL_MATH_PI,
                                     12.0 * DBL_EPSILON, 1600.0 * DBL_EPSILON);
 
+    /* These two pairs of double roots are not handled well */
+    (void)cpl_vector_set(xtrue, 0,  1.0);
+    (void)cpl_vector_set(xtrue, 1,  1.0);
+    (void)cpl_vector_set(xtrue, 2,  3.0);
+    (void)cpl_vector_set(xtrue, 3,  3.0);
+    (void)cpl_vector_set(xtrue, 4,  2.0);
+    (void)cpl_vector_set(xtrue, 5,  1.0);
+
+    irplib_polynomial_test_root_all(xtrue, nreal-2, CPL_MATH_PI,
+                                    0.05, 0.02);
+
+    /* Single pair of double roots - somewhat better */
+    (void)cpl_vector_set(xtrue, 0,  1.0);
+    (void)cpl_vector_set(xtrue, 1,  1.0);
+    (void)cpl_vector_set(xtrue, 2,  2.0);
+    (void)cpl_vector_set(xtrue, 3,  1.0);
+    (void)cpl_vector_set(xtrue, 4,  3.0);
+    (void)cpl_vector_set(xtrue, 5,  3.0);
+
+    irplib_polynomial_test_root_all(xtrue, nreal-4, CPL_MATH_PI,
+                                    FLT_EPSILON, 1600.0 * DBL_EPSILON);
+
+    /* These three pairs of double roots are handled only without scaling */
+    (void)cpl_vector_set(xtrue, 0,  0.0);
+    (void)cpl_vector_set(xtrue, 1,  0.0);
+    (void)cpl_vector_set(xtrue, 2,  1.0);
+    (void)cpl_vector_set(xtrue, 3,  1.0);
+    (void)cpl_vector_set(xtrue, 4,  2.0);
+    (void)cpl_vector_set(xtrue, 5,  2.0);
+
+    irplib_polynomial_test_root_all(xtrue, nreal, 1.0,
+                                    DBL_EPSILON, DBL_EPSILON);
+
+    /* These three pairs of double roots are handled only without scaling */
+    (void)cpl_vector_set(xtrue, 0,  1.0);
+    (void)cpl_vector_set(xtrue, 1,  1.0);
+    (void)cpl_vector_set(xtrue, 2,  2.0);
+    (void)cpl_vector_set(xtrue, 3,  2.0);
+    (void)cpl_vector_set(xtrue, 4,  3.0);
+    (void)cpl_vector_set(xtrue, 5,  3.0);
+
+    irplib_polynomial_test_root_all(xtrue, nreal, 1.0,
+                                    10.0 * FLT_EPSILON, 1500.0 * DBL_EPSILON);
+
+    /* These three pairs of double roots are easy ... */
+    (void)cpl_vector_set(xtrue, 0,  0.0);
+    (void)cpl_vector_set(xtrue, 1,  0.0);
+    (void)cpl_vector_set(xtrue, 2,  0.0);
+    (void)cpl_vector_set(xtrue, 3,  0.0);
+    (void)cpl_vector_set(xtrue, 4,  1.0);
+    (void)cpl_vector_set(xtrue, 5,  1.0);
+
+    irplib_polynomial_test_root_all(xtrue, nreal, CPL_MATH_PI,
+                                    DBL_EPSILON, DBL_EPSILON);
+
+    /* A triple-root */
+    (void)cpl_vector_set(xtrue, 0, -1.0);
+    (void)cpl_vector_set(xtrue, 1,  1.0);
+    (void)cpl_vector_set(xtrue, 2,  1.0);
+    (void)cpl_vector_set(xtrue, 3,  1.0);
+    (void)cpl_vector_set(xtrue, 4,  2.0);
+    (void)cpl_vector_set(xtrue, 5,  3.0);
+
+    irplib_polynomial_test_root_all(xtrue, nreal, CPL_MATH_PI,
+                                    124.0 * FLT_EPSILON, 960e4 * DBL_EPSILON);
+
+#if MAXDEGREE > 6
+    nreal = 7;
+
+    cpl_vector_set_size(xtrue, nreal);
+
+    /* Effectively a triple root */
+    (void)cpl_vector_set(xtrue, 0,  0.0);
+    (void)cpl_vector_set(xtrue, 1,  0.0);
+    (void)cpl_vector_set(xtrue, 2,  0.0);
+    (void)cpl_vector_set(xtrue, 3,  0.0);
+    (void)cpl_vector_set(xtrue, 4,  1.0);
+    (void)cpl_vector_set(xtrue, 5,  1.0);
+    (void)cpl_vector_set(xtrue, 6,  1.0);
+
+    irplib_polynomial_test_root_all(xtrue, nreal, CPL_MATH_PI,
+                                    DBL_EPSILON, DBL_EPSILON);
+
+#if MAXDEGREE > 7
+    nreal = 8;
+
+    cpl_vector_set_size(xtrue, nreal);
+
+    (void)cpl_vector_set(xtrue, 0, -3.0);
+    (void)cpl_vector_set(xtrue, 1, -2.0);
+    (void)cpl_vector_set(xtrue, 2, -1.0);
+    (void)cpl_vector_set(xtrue, 3,  0.0);
+    (void)cpl_vector_set(xtrue, 4,  1.0);
+    (void)cpl_vector_set(xtrue, 5,  2.0);
+    (void)cpl_vector_set(xtrue, 6,  3.0);
+    (void)cpl_vector_set(xtrue, 7,  4.0);
+
+    irplib_polynomial_test_root_all(xtrue, nreal, CPL_MATH_PI,
+                                    50.0 * DBL_EPSILON, 350e3 * DBL_EPSILON);
+
+    (void)cpl_vector_set(xtrue, 0,  1.0);
+    (void)cpl_vector_set(xtrue, 1,  2.0);
+    (void)cpl_vector_set(xtrue, 2,  3.0);
+    (void)cpl_vector_set(xtrue, 3,  4.0);
+    (void)cpl_vector_set(xtrue, 4,  5.0);
+    (void)cpl_vector_set(xtrue, 5,  6.0);
+    (void)cpl_vector_set(xtrue, 6,  7.0);
+    (void)cpl_vector_set(xtrue, 7,  8.0);
+
+    irplib_polynomial_test_root_all(xtrue, nreal, CPL_MATH_PI,
+                                    5e5 * DBL_EPSILON, FLT_EPSILON);
+
+#if MAXDEGREE > 8
+
+    nreal = 0;
+    stol = DBL_EPSILON;
+    rtol = DBL_EPSILON * 1000.0;
+
+    do {
+        nreal++;
+        cpl_vector_set_size(xtrue, nreal);
+
+        for (i = 0; i < nreal; i++) {
+            (void)cpl_vector_set(xtrue, i, (double)i);
+        }
+
+        irplib_polynomial_test_root_all(xtrue, nreal, 1.0,
+                                        stol, rtol);
+        stol *= 6.0;
+        rtol *= 12.0;
+    } while (nreal < MAXDEGREE);
+
+#endif
+#endif
+#endif
 #endif
 #endif
 #endif
@@ -416,9 +584,9 @@ static void irplib_polynomial_solve_1d_all_test(void)
   @brief    Multiply a polynomial by (x-v1)(x-v2)...(x-vn)
   @param    self  The 1D-polynomial to modify
   @param    roots The roots to use for the extension
-  @pram     nreal The number of real roots
+  @param    nreal The number of real roots
   @return   CPL_ERROR_NONE or the relevant CPL error code.
- 
+  @note roots must be sorted (for subsequent comparison)
   
  */
 /*----------------------------------------------------------------------------*/
@@ -430,6 +598,7 @@ cpl_error_code irplib_polynomial_multiply_1d_factor(cpl_polynomial * self,
 
     const cpl_size nroots = cpl_vector_get_size(roots);
     cpl_size       i, degree;
+    double         prevroot = 0.0;  /* Avoid (false) uninit warning */
 
     cpl_ensure_code(self  != NULL, CPL_ERROR_NULL_INPUT);
     cpl_ensure_code(roots != NULL, CPL_ERROR_NULL_INPUT);
@@ -445,7 +614,7 @@ cpl_error_code irplib_polynomial_multiply_1d_factor(cpl_polynomial * self,
     i = 0;
     degree = cpl_polynomial_get_degree(self);
     cpl_ensure_code(degree > 0 || cpl_polynomial_get_coeff(self, &i) != 0.0,
-                     CPL_ERROR_DATA_NOT_FOUND);
+                    CPL_ERROR_DATA_NOT_FOUND);
 
     for (i = 0; i < nreal; i++) {
         const double root = cpl_vector_get(roots, i);
@@ -474,6 +643,10 @@ cpl_error_code irplib_polynomial_multiply_1d_factor(cpl_polynomial * self,
             prev = value;
 
         }
+
+        if (i > 0)
+            cpl_test_leq(prevroot, root);
+        prevroot = root;
     }
 
     /* Multiplication with the complex conjugate root
@@ -488,14 +661,29 @@ cpl_error_code irplib_polynomial_multiply_1d_factor(cpl_polynomial * self,
 
         irplib_polynomial_multiply_1d_factor(self, aroot, 2);
 
-        irplib_polynomial_multiply_scalar(copy, copy, b * b);
+        cpl_test_lt(0.0, fabs(b)); /* Complex root must be complex ... */
 
-        irplib_polynomial_add(self, self, copy);
+        cpl_polynomial_multiply_scalar(copy, copy, b * b);
+
+        cpl_polynomial_add(self, self, copy);
 
         cpl_vector_delete(aroot);
         cpl_polynomial_delete(copy);
 
     }
+    cpl_test_assert(i == nroots);
+
+    for (i = 0; i < nreal; i++) {
+        const double root = cpl_vector_get(roots, i);
+        double d = 0.0;
+        const double resid = cpl_polynomial_eval_1d(self, root, &d);
+        if (resid != 0.0) {
+            cpl_msg_info(cpl_func, "Real, true root %d/%d of %d degree 1D-"
+                         "polynomial at %g has non-zero residual: %g "
+                         "(gradient=%g)",
+                         1+(int)i, (int)nreal, (int)degree, root, resid, d);
+        }
+    }
 
     return CPL_ERROR_NONE;
 
@@ -506,7 +694,7 @@ cpl_error_code irplib_polynomial_multiply_1d_factor(cpl_polynomial * self,
   @internal
   @brief    Test the roots of a 1D-polynomial
   @param    self      The roots to use for the extension
-  @pram     nreal     The number of real roots in self
+  @param    nreal     The number of real roots in self
   @param    factor    The factor of the leading polynomial term
   @param    tolerance The acceptable absolute tolerance on each root
   @param    resitol   The acceptable absolute residual of each root
@@ -526,53 +714,64 @@ irplib_polynomial_test_root_all_macro(const cpl_vector * self, cpl_size nreal,
     cpl_vector * roots = cpl_vector_new(degree);
     cpl_size i = 0;
     cpl_size jreal;
+    cpl_error_code code;
 
-    cpl_test_eq(cpl_polynomial_set_coeff(p1d, &i, factor), CPL_ERROR_NONE);
+    code = cpl_polynomial_set_coeff(p1d, &i, factor);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
 
-    cpl_test_eq(irplib_polynomial_multiply_1d_factor(p1d, self, nreal),
-                CPL_ERROR_NONE);
+    code = irplib_polynomial_multiply_1d_factor(p1d, self, nreal);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
 
-    cpl_test_eq(irplib_polynomial_solve_1d_all(p1d, roots, &jreal),
-                CPL_ERROR_NONE);
+    code = irplib_polynomial_solve_1d_all(p1d, roots, &jreal);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
 
     cpl_test_eq(jreal, nreal);
     if (jreal != nreal) {
-        cpl_msg_info(cpl_func, "1D-polynomial:");
+        cpl_vector * jroots = (jreal == 0 && code) ? NULL :
+            cpl_vector_wrap(code ? jreal : CPL_MAX(nreal, jreal),
+                            cpl_vector_get_data(roots));
+
+        cpl_msg_info(cpl_func, "1D-polynomial of degree %d:", (int)degree);
         cpl_polynomial_dump(p1d, stderr);
         cpl_msg_error(cpl_func, "True roots (%" CPL_SIZE_FORMAT
                       " real): (line=%u)", nreal, line);
         cpl_vector_dump(self, stderr);
         cpl_msg_error(cpl_func, "Computed roots (%" CPL_SIZE_FORMAT " real): ",
                       jreal);
-        cpl_vector_dump(roots, stderr);
-    } else if (cpl_msg_get_level() < CPL_MSG_WARNING) {
-        cpl_bivector * dump =
-            cpl_bivector_wrap_vectors((cpl_vector*)self, roots);
+        cpl_vector_dump(jroots, stderr);
+        (void)cpl_vector_unwrap(jroots);
+    } else {
+        if (cpl_msg_get_level() < CPL_MSG_WARNING) {
+            CPL_DIAG_PRAGMA_PUSH_IGN(-Wcast-qual)
+                cpl_bivector * dump =
+                cpl_bivector_wrap_vectors((cpl_vector*)self, roots);
+            CPL_DIAG_PRAGMA_POP;
 
-        cpl_msg_warning(cpl_func, "Comparing %" CPL_SIZE_FORMAT " roots (%"
-                        CPL_SIZE_FORMAT " real): (line=%u)",
-                        degree, nreal, line);
-        cpl_bivector_dump(dump, stderr);
-        cpl_bivector_unwrap_vectors(dump);
-    }
+            cpl_msg_warning(cpl_func, "Comparing %" CPL_SIZE_FORMAT " roots (%"
+                            CPL_SIZE_FORMAT " real): (line=%u)",
+                            degree, nreal, line);
+            cpl_bivector_dump(dump, stderr);
+            cpl_bivector_unwrap_vectors(dump);
+        }
 
-    for (i = 0; i < jreal; i++) {
-        const double root = cpl_vector_get(roots, i);
-        const double residual = cpl_polynomial_eval_1d(p1d, root, NULL);
+        for (i = 0; i < jreal; i++) {
+            const double root = cpl_vector_get(roots, i);
+            const double residual = cpl_polynomial_eval_1d(p1d, root, NULL);
 
-        cpl_test_abs(root, cpl_vector_get(self, i), tolerance);
+            cpl_test_abs(root, cpl_vector_get(self, i), tolerance);
 
-        cpl_test_abs(residual, 0.0, resitol);
+            cpl_test_abs(residual, 0.0, resitol);
 
-    }
+        }
 
-    for (i = nreal; i < degree; i++) {
-        const double root = cpl_vector_get(roots, i);
+        for (i = nreal; i < degree; i++) {
+            const double root = cpl_vector_get(roots, i);
 
-        cpl_test_abs(root, cpl_vector_get(self, i), tolerance);
+            cpl_test_abs(root, cpl_vector_get(self, i), tolerance);
 
-        /* FIXME: Verify residual as well */
+            /* FIXME: Verify residual as well */
 
+        }
     }
 
     cpl_vector_delete(roots);
