@@ -2177,6 +2177,9 @@ static cpl_error_code visir_get_filter_infos(
     else if (!strcmp(f, "B12.4") || !strcmp(f, "B12_4"))
         { cwlen = (11.971 + 12.961)/2.0;
             dwlen = 12.961 - 11.971;}
+    else if (!strcmp(f, "L-BAND") || !strcmp(f, "L_BAND"))
+        { cwlen = 3.7702; //(3.4195 + 4.0610)/2.0;
+            dwlen = 4.0610 - 3.4195;}
 
     *pcwlen = cwlen;
     *pdwlen = dwlen;
