@@ -26,10 +26,6 @@
   Includes
   -----------------------------------------------------------------------------*/
 
-#ifndef _XOPEN_SOURCE
-#define _XOPEN_SOURCE 600 /* setenv */
-#endif
-
 #ifndef ESO_COVERAGE_BUILD
 #define ESO_COVERAGE_BUILD 0
 #endif
