@@ -91,6 +91,9 @@ VISIR_RECIPE_DEFINE(visir_old_spc_obs_ech,
                     VISIR_PARAM_SPECSKEW | VISIR_PARAM_VERTARC |
                     VISIR_PARAM_REJLEFT | VISIR_PARAM_REJRIGHT |
                     VISIR_PARAM_HORIARC | VISIR_PARAM_FIXCOMBI |
+                    VISIR_PARAM_GAIN | VISIR_PARAM_RONOISE |
+                    VISIR_PARAM_OXSIGMA | VISIR_PARAM_OXNITER |
+                    VISIR_PARAM_OXSMOOTH | VISIR_PARAM_OXKERNEL |
                     VISIR_PARAM_BKG_CORRECT,
                     "Old DRS detector: Spectroscopic Observation recipe in Echelle mode",
                     "This recipe estimates the dispersion relation using the "
@@ -157,7 +160,6 @@ static int visir_old_spc_obs_ech(cpl_frameset            * framelist,
     visir_spc_resol     resol;
     cpl_boolean        drop_wcs;
     int                input_mode;
-    cpl_boolean        bkgcorrect;
     cpl_errorstate     cleanstate = cpl_errorstate_get();
     visir_spc_config   spc_config;
     const char       * dit_key = VISIR_PFITS_DOUBLE_DIT;
@@ -169,28 +171,37 @@ static int visir_old_spc_obs_ech(cpl_frameset            * framelist,
     spc_config.phot_emis_tol = 1.0;
 
     /* Retrieve input parameters */
-    spc_config.plot =
-        visir_parameterlist_get_int(parlist, RECIPE_STRING, VISIR_PARAM_PLOT);
+    spc_config.plot = visir_parameterlist_get_int(
+            parlist, RECIPE_STRING, VISIR_PARAM_PLOT);
+    spc_config.phi = visir_parameterlist_get_double(
+            parlist, RECIPE_STRING, VISIR_PARAM_SLITSKEW);
+    spc_config.ksi = visir_parameterlist_get_double(
+            parlist, RECIPE_STRING, VISIR_PARAM_SPECSKEW);
+    spc_config.eps = visir_parameterlist_get_double(
+            parlist, RECIPE_STRING, VISIR_PARAM_VERTARC);
+    spc_config.delta = visir_parameterlist_get_double(
+            parlist, RECIPE_STRING, VISIR_PARAM_HORIARC);
+    spc_config.gain = visir_parameterlist_get_double(
+            parlist, RECIPE_STRING, VISIR_PARAM_GAIN);
+    spc_config.ron = visir_parameterlist_get_double(
+            parlist, RECIPE_STRING, VISIR_PARAM_RONOISE);
+    spc_config.ox_sigma = visir_parameterlist_get_double(
+            parlist, RECIPE_STRING, VISIR_PARAM_OXSIGMA);
+    spc_config.ox_niters = visir_parameterlist_get_int(
+            parlist, RECIPE_STRING, VISIR_PARAM_OXNITER);
+    spc_config.ox_smooth = visir_parameterlist_get_int(
+            parlist, RECIPE_STRING, VISIR_PARAM_OXSMOOTH);
+    spc_config.ox_kernel = visir_parameterlist_get_int(
+            parlist, RECIPE_STRING, VISIR_PARAM_OXKERNEL);
+    spc_config.orderoffset = visir_parameterlist_get_int(
+            parlist, RECIPE_STRING, VISIR_PARAM_ORDEROFF);
+    spc_config.do_fixcombi = visir_parameterlist_get_bool(
+            parlist, RECIPE_STRING, VISIR_PARAM_FIXCOMBI);
+    spc_config.phot_emis_tol = visir_parameterlist_get_double(
+            parlist, RECIPE_STRING, VISIR_PARAM_EMIS_TOL);
+    spc_config.bkgcorrect = visir_parameterlist_get_bool(
+            parlist, RECIPE_STRING, VISIR_PARAM_BKG_CORRECT);
 
-    spc_config.phi =
-        visir_parameterlist_get_double(parlist,RECIPE_STRING,VISIR_PARAM_SLITSKEW);
-    spc_config.ksi =
-        visir_parameterlist_get_double(parlist,RECIPE_STRING,VISIR_PARAM_SPECSKEW);
-    spc_config.eps =
-        visir_parameterlist_get_double(parlist, RECIPE_STRING,VISIR_PARAM_VERTARC);
-    spc_config.delta =
-        visir_parameterlist_get_double(parlist, RECIPE_STRING,VISIR_PARAM_HORIARC);
-
-    spc_config.orderoffset =
-        visir_parameterlist_get_int(parlist, RECIPE_STRING, VISIR_PARAM_ORDEROFF);
-
-    spc_config.do_fixcombi = visir_parameterlist_get_bool(parlist, RECIPE_STRING,
-                                                          VISIR_PARAM_FIXCOMBI);
-    spc_config.phot_emis_tol =
-        visir_parameterlist_get_double(parlist, RECIPE_STRING, VISIR_PARAM_EMIS_TOL);
-
-    bkgcorrect = visir_parameterlist_get_bool(parlist, RECIPE_STRING,
-                                              VISIR_PARAM_BKG_CORRECT);
     skip_if (0);
 
     /* Identify the RAW and CALIB frames in the input frameset */
@@ -213,6 +224,7 @@ static int visir_old_spc_obs_ech(cpl_frameset            * framelist,
         input_mode = RAW_INPUT;
     }
     skip_if (rawframes == NULL);
+    const cpl_size nframes = irplib_framelist_get_size(rawframes);
 
     irplib_framelist_empty(allframes);
 
@@ -222,6 +234,7 @@ static int visir_old_spc_obs_ech(cpl_frameset            * framelist,
                                                    "|" RECIPE_KEYS_REGEXP_WCS
                                                    "|" VISIR_PFITS_REGEXP_DIT
                                                    "|" "ESO DRS .*"
+                                                   "|" "ESO PRO DATANCOM"
                                                    "|" "ESO QC EXPTIME"
                                                    "|" "ESO QC BACKGD MEAN"
                                                    ")$", CPL_FALSE));
@@ -273,7 +286,6 @@ static int visir_old_spc_obs_ech(cpl_frameset            * framelist,
 
     if (input_mode == PREPROCESSED_INPUT) {
         cpl_imagelist * imagelist = cpl_imagelist_new();
-        cpl_size nframes = irplib_framelist_get_size(rawframes);
         const cpl_propertylist ** plists =
             cpl_malloc(nframes * sizeof(cpl_propertylist *));
         double bg_sum = 0;
@@ -305,12 +317,9 @@ static int visir_old_spc_obs_ech(cpl_frameset            * framelist,
             }
             tmp = cpl_imagelist_collapse_create(tmplist);
 
-            skip_if (visir_spc_det_fix(&tmp, 1, CPL_TRUE,
-                                       wlen, resol,
-                                       spc_config.phi,
-                                       spc_config.ksi,
-                                       spc_config.eps,
-                                       spc_config.delta,
+            skip_if (visir_spc_det_fix(&tmp, 1, CPL_TRUE, wlen, resol,
+                                       spc_config.phi, spc_config.ksi,
+                                       spc_config.eps, spc_config.delta,
                                        spc_config.plot));
             cpl_imagelist_set(imagelist, tmp,
                               cpl_imagelist_get_size(imagelist));
@@ -335,12 +344,9 @@ static int visir_old_spc_obs_ech(cpl_frameset            * framelist,
             skip_if(imhcycle == NULL);
         }
 
-        skip_if (visir_spc_det_fix(&imhcycle, 1, CPL_TRUE,
-                                   wlen, resol,
-                                   spc_config.phi,
-                                   spc_config.ksi,
-                                   spc_config.eps,
-                                   spc_config.delta,
+        skip_if (visir_spc_det_fix(&imhcycle, 1, CPL_TRUE, wlen, resol,
+                                   spc_config.phi, spc_config.ksi,
+                                   spc_config.eps, spc_config.delta,
                                    spc_config.plot));
 
     } else if (input_mode == RAW_INPUT) {
@@ -354,12 +360,9 @@ static int visir_old_spc_obs_ech(cpl_frameset            * framelist,
 
         imhcycle = cpl_imagelist_unset(hcycle, 0);
 
-        skip_if (visir_spc_det_fix(&imhcycle, 1, CPL_FALSE,
-                                   wlen, resol,
-                                   spc_config.phi,
-                                   spc_config.ksi,
-                                   spc_config.eps,
-                                   spc_config.delta,
+        skip_if (visir_spc_det_fix(&imhcycle, 1, CPL_FALSE, wlen, resol,
+                                   spc_config.phi, spc_config.ksi,
+                                   spc_config.eps, spc_config.delta,
                                    spc_config.plot));
 
         skip_if(visir_qc_append_background(qclist, rawframes, 0, 0));
@@ -379,7 +382,8 @@ static int visir_old_spc_obs_ech(cpl_frameset            * framelist,
 
     /* Convert the combined image
      * recipe only supported with drs data */
-    flipped = visir_spc_flip(combined, wlen, resol, VISIR_DATA_CUBE2);
+    bool rev;
+    flipped = visir_spc_flip(combined, wlen, resol, VISIR_DATA_CUBE2, &rev);
     skip_if (0);
     cpl_image_delete(combined);
     combined = flipped;
@@ -387,7 +391,7 @@ static int visir_old_spc_obs_ech(cpl_frameset            * framelist,
 
     /* Convert the half cycle image
      * recipe only supported with drs data */
-    flipped = visir_spc_flip(imhcycle, wlen, resol, VISIR_DATA_CUBE2);
+    flipped = visir_spc_flip(imhcycle, wlen, resol, VISIR_DATA_CUBE2, NULL);
     skip_if (0);
     cpl_image_delete(imhcycle);
     imhcycle = flipped;
@@ -396,26 +400,29 @@ static int visir_old_spc_obs_ech(cpl_frameset            * framelist,
     skip_if (0);
 
     skip_if (spc_config.do_fixcombi && input_mode == RAW_INPUT &&
-             visir_spc_det_fix(&combined, 1, CPL_TRUE,
-                               wlen, resol,
-                               spc_config.phi,
-                               spc_config.ksi,
-                               spc_config.eps,
-                               spc_config.delta,
+             visir_spc_det_fix(&combined, 1, CPL_TRUE, wlen, resol,
+                               spc_config.phi, spc_config.ksi,
+                               spc_config.eps, spc_config.delta,
                                spc_config.plot));
 
-    skip_if(visir_spc_extract_order(&imhcyclenarrow, &comnarrow,
-                                    combined, imhcycle, wlen,
-                                    &spc_config, CPL_TRUE,
-                                    visir_data_is_aqu(data_type)));
+    const int ncomb = visir_get_ncombine(rawframes);
+    skip_if (!ncomb);
 
-    skip_if (visir_spc_extract_wcal(comnarrow, imhcyclenarrow,
-                                    wlen, slitw, temp, fwhm,
-                                    resol, spc_config.orderoffset,
+    int lcol = -1, rcol = -1;
+    skip_if (visir_spc_extract_order(&imhcyclenarrow, &comnarrow, &lcol, &rcol,
+                                     combined, imhcycle, wlen, &spc_config,
+                                     CPL_TRUE, visir_data_is_aqu(data_type)));
+
+    int const ident = -1;  // neg ident: use old extract alg
+    visir_apdefs * const aps = visir_apdefs_new(1, ident, 'O', 0);
+    aps->limits[0] = (visir_aplimits){ lcol, rcol };
+
+    skip_if (visir_spc_extract_wcal(comnarrow, imhcyclenarrow, lcol, rcol, wlen,
+                                    slitw, temp, fwhm, resol, &spc_config,
                                     spc_cal_lines, spc_cal_qeff,
-                                    &spc_table, &weight2d, qclist,
-                                    spc_config.plot, bkgcorrect,
-                                    visir_data_is_aqu(data_type)));
+                                    visir_data_is_aqu(data_type), aps, ncomb,
+                                    rev, &spc_table, &weight2d, qclist));
+                                    
 
 
     bug_if (visir_spectro_qc(qclist, paflist, drop_wcs, rawframes, NULL,
@@ -426,6 +433,7 @@ static int visir_old_spc_obs_ech(cpl_frameset            * framelist,
         const cpl_propertylist * plist =
             irplib_framelist_get_propertylist_const(rawframes, 0);
         skip_if(0);
+        spc_config.phu = qclist;
         if (visir_spc_phot_sensit(rawframes, &spc_config, plist, star_cat,
                                   &weight2d, qclist, spc_table, resol,
                                   dit_key)) {
