@@ -87,7 +87,10 @@ VISIR_RECIPE_DEFINE(visir_old_spc_phot_ech,
                     VISIR_PARAM_PLOT   | VISIR_PARAM_SLITSKEW |
                     VISIR_PARAM_SPECSKEW | VISIR_PARAM_VERTARC |
                     VISIR_PARAM_REJLEFT | VISIR_PARAM_REJRIGHT |
-                    VISIR_PARAM_HORIARC | VISIR_PARAM_FIXCOMBI,
+                    VISIR_PARAM_HORIARC | VISIR_PARAM_FIXCOMBI |
+                    VISIR_PARAM_GAIN | VISIR_PARAM_RONOISE |
+                    VISIR_PARAM_OXSIGMA | VISIR_PARAM_OXNITER |
+                    VISIR_PARAM_OXSMOOTH | VISIR_PARAM_OXKERNEL,
                     "Old DRS detector: Sensitivity computation in echelle spectroscopy",
                     "This recipe estimates the dispersion relation using the "
                     "atmospheric spectrum\n"
@@ -156,26 +159,35 @@ static int visir_old_spc_phot_ech(cpl_frameset            * framelist,
     config.parlist = parlist;
 
     /* Retrieve input parameters */
-    config.do_fixcombi =
-        visir_parameterlist_get_bool(parlist, RECIPE_STRING, VISIR_PARAM_FIXCOMBI);
-
-    config.plot =
-        visir_parameterlist_get_int(parlist, RECIPE_STRING, VISIR_PARAM_PLOT);
-
-    config.phi =
-        visir_parameterlist_get_double(parlist, RECIPE_STRING, VISIR_PARAM_SLITSKEW);
-    config.ksi =
-        visir_parameterlist_get_double(parlist, RECIPE_STRING, VISIR_PARAM_SPECSKEW);
-    config.eps =
-        visir_parameterlist_get_double(parlist, RECIPE_STRING, VISIR_PARAM_VERTARC);
-    config.delta =
-        visir_parameterlist_get_double(parlist, RECIPE_STRING, VISIR_PARAM_HORIARC);
-
-    config.orderoffset =
-        visir_parameterlist_get_int(parlist, RECIPE_STRING, VISIR_PARAM_ORDEROFF);
-
-    config.phot_emis_tol =
-        visir_parameterlist_get_double(parlist, RECIPE_STRING, VISIR_PARAM_EMIS_TOL);
+    config.do_fixcombi = visir_parameterlist_get_bool(
+            parlist, RECIPE_STRING, VISIR_PARAM_FIXCOMBI);
+    config.plot = visir_parameterlist_get_int(
+            parlist, RECIPE_STRING, VISIR_PARAM_PLOT);
+    config.phi = visir_parameterlist_get_double(
+            parlist, RECIPE_STRING, VISIR_PARAM_SLITSKEW);
+    config.ksi = visir_parameterlist_get_double(
+            parlist, RECIPE_STRING, VISIR_PARAM_SPECSKEW);
+    config.eps = visir_parameterlist_get_double(
+            parlist, RECIPE_STRING, VISIR_PARAM_VERTARC);
+    config.delta = visir_parameterlist_get_double(
+            parlist, RECIPE_STRING, VISIR_PARAM_HORIARC);
+    config.gain = visir_parameterlist_get_double(
+            parlist, RECIPE_STRING, VISIR_PARAM_GAIN);
+    config.ron = visir_parameterlist_get_double(
+            parlist, RECIPE_STRING, VISIR_PARAM_RONOISE);
+    config.ox_sigma = visir_parameterlist_get_double(
+            parlist, RECIPE_STRING, VISIR_PARAM_OXSIGMA);
+    config.ox_niters = visir_parameterlist_get_int(
+            parlist, RECIPE_STRING, VISIR_PARAM_OXNITER);
+    config.ox_smooth = visir_parameterlist_get_int(
+            parlist, RECIPE_STRING, VISIR_PARAM_OXSMOOTH);
+    config.ox_kernel = visir_parameterlist_get_int(
+            parlist, RECIPE_STRING, VISIR_PARAM_OXKERNEL);
+    config.orderoffset = visir_parameterlist_get_int(
+            parlist, RECIPE_STRING, VISIR_PARAM_ORDEROFF);
+    config.phot_emis_tol = visir_parameterlist_get_double(
+            parlist, RECIPE_STRING, VISIR_PARAM_EMIS_TOL);
+    config.bkgcorrect = CPL_FALSE;
 
     skip_if (0);
 
@@ -184,7 +196,7 @@ static int visir_old_spc_phot_ech(cpl_frameset            * framelist,
 
     /* Objects observation */
     allframes = irplib_framelist_cast(framelist);
-    skip_if(allframes == NULL);
+    skip_if (allframes == NULL);
     rawframes = irplib_framelist_extract(allframes, VISIR_SPC_PHOT_ECH_RAW);
     skip_if (rawframes == NULL);
 
@@ -256,6 +268,7 @@ static int visir_old_spc_phot_ech(cpl_frameset            * framelist,
 
     /* Compute here the sensitivity */
     cpl_msg_info(cpl_func, "Compute the sensitivity");
+    config.phu = qclist;
     tab = visir_spc_phot_sensit_from_image(&combined, rawframes, &config,
                                            star_cat, spc_cal_lines,
                                            spc_cal_qeff, &weight2d, qclist,
