@@ -74,21 +74,6 @@ VISIR_RECIPE_DEFINE(visir_old_spc_wcal,
                     "\n"
                     MAN_VISIR_CALIB_BPM_SPC);
 
-/*-----------------------------------------------------------------------------
-                            Static variables
- -----------------------------------------------------------------------------*/
-
-static struct {
-    /* Inputs */
-    int         auto_bpm;
-    int         plot;
-    double      phi;
-    double      ksi;
-    double      eps;
-    double      delta;
-
-} visir_spc_wcal_config;
-
 /*----------------------------------------------------------------------------*/
 /**
  * @defgroup visir_spc_wcal   Spectroscopic wavelength calibration
@@ -110,35 +95,36 @@ static struct {
 static int visir_old_spc_wcal(cpl_frameset            * framelist,
                           const cpl_parameterlist * parlist)
 {
-    irplib_framelist * allframes = NULL;
-    irplib_framelist * rawframes = NULL;
-    cpl_propertylist * qclist    = cpl_propertylist_new();
-    cpl_propertylist * paflist   = cpl_propertylist_new();
-    const char      *   spc_cal_qeff;
-    const char      *   spc_cal_lines;
-    cpl_imagelist   *   hcycle = NULL;
-    cpl_image       *   imhcycle = NULL;
-    cpl_image       *   flipped = NULL;
-    cpl_image       *   imhcyclenarrow = NULL;
-    cpl_table       *   spc_table = NULL;
+    irplib_framelist *  allframes = NULL;
+    irplib_framelist *  rawframes = NULL;
+    cpl_propertylist *  qclist    = cpl_propertylist_new();
+    cpl_propertylist *  paflist   = cpl_propertylist_new();
+    const char       *  spc_cal_qeff;
+    const char       *  spc_cal_lines;
+    cpl_imagelist    *  hcycle = NULL;
+    cpl_image        *  imhcycle = NULL;
+    cpl_image        *  flipped = NULL;
+    cpl_image        *  imhcyclenarrow = NULL;
+    cpl_table        *  spc_table = NULL;
     double              wlen, slitw, temp, fwhm;
     visir_spc_resol     resol;
-    int                icol1, icol2;
-    int                jcol1, jcol2;
+    int                 icol1, icol2;
+    int                 jcol1, jcol2;
+    visir_spc_config    cfg;
 
 
-    visir_spc_wcal_config.auto_bpm = 
-        visir_parameterlist_get_bool(parlist, RECIPE_STRING, VISIR_PARAM_AUTOBPM);
-    visir_spc_wcal_config.plot = visir_parameterlist_get_int(parlist, RECIPE_STRING, VISIR_PARAM_PLOT);
-
-    visir_spc_wcal_config.phi = 
-        visir_parameterlist_get_double(parlist, RECIPE_STRING, VISIR_PARAM_SLITSKEW);
-    visir_spc_wcal_config.ksi = 
-        visir_parameterlist_get_double(parlist, RECIPE_STRING, VISIR_PARAM_SPECSKEW);
-    visir_spc_wcal_config.eps = 
-        visir_parameterlist_get_double(parlist, RECIPE_STRING, VISIR_PARAM_VERTARC);
-    visir_spc_wcal_config.delta = 
-        visir_parameterlist_get_double(parlist, RECIPE_STRING, VISIR_PARAM_HORIARC);
+    cfg.auto_bpm = visir_parameterlist_get_bool(
+            parlist, RECIPE_STRING, VISIR_PARAM_AUTOBPM);
+    cfg.plot = visir_parameterlist_get_int(
+            parlist, RECIPE_STRING, VISIR_PARAM_PLOT);
+    cfg.phi = visir_parameterlist_get_double(
+            parlist, RECIPE_STRING, VISIR_PARAM_SLITSKEW);
+    cfg.ksi = visir_parameterlist_get_double(
+            parlist, RECIPE_STRING, VISIR_PARAM_SPECSKEW);
+    cfg.eps = visir_parameterlist_get_double(
+            parlist, RECIPE_STRING, VISIR_PARAM_VERTARC);
+    cfg.delta = visir_parameterlist_get_double(
+            parlist, RECIPE_STRING, VISIR_PARAM_HORIARC);
 
     jcol1 = visir_parameterlist_get_int(parlist, RECIPE_STRING,
                                         VISIR_PARAM_REJLEFT);
@@ -188,19 +174,14 @@ static int visir_old_spc_wcal(cpl_frameset            * framelist,
     imhcycle = cpl_imagelist_unset(hcycle, 0);
 
     /* Convert the combined image */
-    flipped = visir_spc_flip(imhcycle, wlen, resol, VISIR_DATA_CUBE2);
+    flipped = visir_spc_flip(imhcycle, wlen, resol, VISIR_DATA_CUBE2, NULL);
     skip_if (0);
     cpl_image_delete(imhcycle);
     imhcycle = flipped;
     flipped = NULL;
 
-    skip_if (visir_spc_det_fix(&imhcycle, 1, CPL_FALSE,
-                               wlen, resol,
-                               visir_spc_wcal_config.phi,
-                               visir_spc_wcal_config.ksi,
-                               visir_spc_wcal_config.eps,
-                               visir_spc_wcal_config.delta, 
-                               visir_spc_wcal_config.plot));
+    skip_if (visir_spc_det_fix(&imhcycle, 1, CPL_FALSE, wlen, resol, cfg.phi,
+                               cfg.ksi, cfg.eps, cfg.delta, cfg.plot));
 
     icol1 = 1;
     icol2 = cpl_image_get_size_x(imhcycle);
@@ -216,7 +197,7 @@ static int visir_old_spc_wcal(cpl_frameset            * framelist,
 
     if (jcol1 != 0 || jcol2 != 0) {
         imhcyclenarrow = visir_spc_column_extract(imhcycle, icol1, icol2,
-                                          visir_spc_wcal_config.plot);
+                                                  cfg.plot);
         skip_if (0);
 
     } else {
@@ -224,9 +205,8 @@ static int visir_old_spc_wcal(cpl_frameset            * framelist,
     }
 
     skip_if (visir_spc_wavecal(imhcyclenarrow, qclist, wlen, slitw, temp, fwhm,
-                               resol, 0,
-                               spc_cal_lines, spc_cal_qeff,
-                               &spc_table, visir_spc_wcal_config.plot, 0));
+                               resol, &cfg, spc_cal_lines, spc_cal_qeff,
+                               &spc_table, 0));
 
     /* This column is not part of the product */
     skip_if (cpl_table_erase_column(spc_table, "SPC_EMISSIVITY"));
