@@ -74,23 +74,6 @@ VISIR_RECIPE_DEFINE(visir_old_spc_wcal_ech,
                     "\n"
                     MAN_VISIR_CALIB_BPM_SPC);
 
-/*-----------------------------------------------------------------------------
-                            Static variables
- -----------------------------------------------------------------------------*/
-
-static struct {
-    /* Inputs */
-    int         auto_bpm;
-    int         plot;
-    int         orderoffset;
-    double      phi;
-    double      ksi;
-    double      eps;
-    double      delta;
-
-} visir_spc_wcal_ech_config;
-
-
 /*----------------------------------------------------------------------------*/
 /**
  * @defgroup visir_spc_wcal_ech   Echelle Spectroscopic Wavelength Calibration
@@ -127,24 +110,23 @@ static int visir_old_spc_wcal_ech(cpl_frameset            * framelist,
     int                 icol1, icol2;
     int                 jcol1, jcol2;
     visir_spc_resol     resol;
+    visir_spc_config    cfg;
 
 
-    visir_spc_wcal_ech_config.auto_bpm = 
-        visir_parameterlist_get_bool(parlist, RECIPE_STRING, VISIR_PARAM_AUTOBPM);
-    visir_spc_wcal_ech_config.plot =
-        visir_parameterlist_get_int(parlist, RECIPE_STRING, VISIR_PARAM_PLOT);
-
-    visir_spc_wcal_ech_config.phi = 
-        visir_parameterlist_get_double(parlist,RECIPE_STRING,VISIR_PARAM_SLITSKEW);
-    visir_spc_wcal_ech_config.ksi = 
-        visir_parameterlist_get_double(parlist,RECIPE_STRING,VISIR_PARAM_SPECSKEW);
-    visir_spc_wcal_ech_config.eps = 
-        visir_parameterlist_get_double(parlist,RECIPE_STRING, VISIR_PARAM_VERTARC);
-    visir_spc_wcal_ech_config.delta = 
-        visir_parameterlist_get_double(parlist,RECIPE_STRING, VISIR_PARAM_HORIARC);
-
-    visir_spc_wcal_ech_config.orderoffset = 
-        visir_parameterlist_get_int(parlist, RECIPE_STRING, VISIR_PARAM_ORDEROFF);
+    cfg.auto_bpm = visir_parameterlist_get_bool(
+            parlist, RECIPE_STRING, VISIR_PARAM_AUTOBPM);
+    cfg.plot = visir_parameterlist_get_int(
+            parlist, RECIPE_STRING, VISIR_PARAM_PLOT);
+    cfg.phi = visir_parameterlist_get_double(
+            parlist, RECIPE_STRING, VISIR_PARAM_SLITSKEW);
+    cfg.ksi = visir_parameterlist_get_double(
+            parlist, RECIPE_STRING, VISIR_PARAM_SPECSKEW);
+    cfg.eps = visir_parameterlist_get_double(
+            parlist, RECIPE_STRING, VISIR_PARAM_VERTARC);
+    cfg.delta = visir_parameterlist_get_double(
+            parlist, RECIPE_STRING, VISIR_PARAM_HORIARC);
+    cfg.orderoffset = visir_parameterlist_get_int(
+            parlist, RECIPE_STRING, VISIR_PARAM_ORDEROFF);
 
     jcol1 = visir_parameterlist_get_int(parlist, RECIPE_STRING,
                                         VISIR_PARAM_REJLEFT);
@@ -180,12 +162,12 @@ static int visir_old_spc_wcal_ech(cpl_frameset            * framelist,
     skip_if (0);
 
     if (resol != VISIR_SPC_R_GHR) {
-        if (visir_spc_wcal_ech_config.orderoffset == 0) {
+        if (cfg.orderoffset == 0) {
             cpl_msg_warning(cpl_func,"Reducing non-HR Grism data as main order");
         } else {
             cpl_msg_error(cpl_func, "This recipe cannot reduce non-HR Grism "
                           "data with an order-offset of %d",
-                          visir_spc_wcal_ech_config.orderoffset);
+                          cfg.orderoffset);
             visir_error_set(CPL_ERROR_TYPE_MISMATCH);
             skip_if(1);
         }
@@ -199,23 +181,17 @@ static int visir_old_spc_wcal_ech(cpl_frameset            * framelist,
 
     /* Convert the combined image
      * recipe only supported with drs data */
-    flipped = visir_spc_flip(imhcycle, wlen, resol, VISIR_DATA_CUBE2);
+    flipped = visir_spc_flip(imhcycle, wlen, resol, VISIR_DATA_CUBE2, NULL);
     skip_if (0);
     cpl_image_delete(imhcycle);
     imhcycle = flipped;
     flipped = NULL;
 
-    skip_if (visir_spc_det_fix(&imhcycle, 1, CPL_FALSE,
-                               wlen, resol,
-                               visir_spc_wcal_ech_config.phi,
-                               visir_spc_wcal_ech_config.ksi,
-                               visir_spc_wcal_ech_config.eps,
-                               visir_spc_wcal_ech_config.delta, 
-                               visir_spc_wcal_ech_config.plot));
+    skip_if (visir_spc_det_fix(&imhcycle, 1, CPL_FALSE, wlen, resol, cfg.phi,
+                               cfg.ksi, cfg.eps, cfg.delta, cfg.plot));
 
-    skip_if (visir_spc_echelle_limit(&icol1, &icol2, wlen,
-                                     visir_spc_wcal_ech_config.orderoffset, 1,
-                           cpl_image_get_size_y(imhcycle), 0));
+    skip_if (visir_spc_echelle_limit(&icol1, &icol2, wlen, &cfg, 1,
+                                     cpl_image_get_size_y(imhcycle), 0));
 
     skip_if(visir_qc_append_background(qclist, rawframes, icol1, icol2));
 
@@ -232,8 +208,7 @@ static int visir_old_spc_wcal_ech(cpl_frameset            * framelist,
 
     if (icol1 != 1 || icol2 != cpl_image_get_size_x(imhcycle)) {
 
-        order = visir_spc_column_extract(imhcycle, icol1, icol2,
-                                          visir_spc_wcal_ech_config.plot);
+        order = visir_spc_column_extract(imhcycle, icol1, icol2, cfg.plot);
         skip_if (0);
     } else {
         /* Cannot really succeed from here... */
@@ -241,9 +216,8 @@ static int visir_old_spc_wcal_ech(cpl_frameset            * framelist,
     }
 
     skip_if (visir_spc_wavecal(order, qclist, wlen, slitw, temp, fwhm, resol,
-                               visir_spc_wcal_ech_config.orderoffset,
-                               spc_cal_lines, spc_cal_qeff,
-                               &spc_table, visir_spc_wcal_ech_config.plot, 0));
+                               &cfg, spc_cal_lines, spc_cal_qeff, &spc_table,
+                               0));
 
     /* This column is not part of the product */
     skip_if (cpl_table_erase_column(spc_table, "SPC_EMISSIVITY"));
