@@ -233,6 +233,8 @@ planelist_from_frame(const cpl_frame * frame)
 
     plist = cpl_propertylist_load(fn, 0);
     skip_if(plist == NULL);
+    // Remove/rename keywords as required
+    visir_dfs_update_header(plist);
     planelist = cx_list_new();
 
     img = cpl_image_load(fn, CPL_TYPE_UNSPECIFIED, 0, 0);
@@ -253,6 +255,8 @@ planelist_from_frame(const cpl_frame * frame)
         skip_if(0);
         plist = cpl_propertylist_load(fn, e);
         skip_if(plist == NULL);
+        // Remove/rename keywords as required
+        visir_dfs_update_header(plist);
         cx_list_push_back(planelist, visir_plane_new(img, tbl, plist));
         img = NULL;
         tbl = NULL;
@@ -426,14 +430,14 @@ propagate_all(cpl_frameset * framelist, const cpl_parameterlist * parlist,
 
 
 static cpl_table *
-calibrate_frame(const cpl_frame * frm, const cpl_bivector * std,
-                const cpl_bivector * stde)
+calibrate_frame(const cpl_frame * frm, const int ext,
+                const cpl_bivector * std, const cpl_bivector * stde)
 {
     const char * dfn = cpl_frame_get_filename(frm);
     const cpl_vector * swlen = cpl_bivector_get_x_const(std);
     cpl_bivector * intstd = NULL;
     cpl_bivector * intstde = NULL;
-    cpl_table * obj = cpl_table_load(dfn, 1, 0);
+    cpl_table * obj = cpl_table_load(dfn, ext, 0);
     skip_if(obj == NULL);
     const size_t n = cpl_table_get_nrow(obj);
 
@@ -534,33 +538,38 @@ get_spec_std(cpl_frameset            * framelist,
     const cpl_frame * frm;
     cpl_bivector * std = NULL;
     cpl_bivector * stde = NULL;
+    int n_std_ext = 0;
+    const char* std_fn = NULL;
     skip_if(stdtab == NULL);
     skip_if(objtab == NULL);
+    /* Check there is only one standard frame supplied */
     cpl_ensure_code(irplib_framelist_get_size(stdtab) == 1,
                     CPL_ERROR_UNSUPPORTED_MODE);
+    /* Check that there is at least one object frame */
     cpl_ensure_code(irplib_framelist_get_size(objtab) > 0,
                     CPL_ERROR_UNSUPPORTED_MODE);
 
+    /* Get the standard frame */
     frm = irplib_framelist_get_const(stdtab, 0);
     skip_if(frm == NULL);
-    {
-        const char * fn = cpl_frame_get_filename(frm);
-        cpl_bivector * model = visir_bivector_load_fits(fn, "WLEN",
-                                                        "STD_STAR_MODEL", 1);
-        std = visir_bivector_load_fits(fn, "WLEN", "SPC_EXTRACTED", 1);
-        stde = visir_bivector_load_fits(fn, "WLEN", "SPC_ERROR", 1);
-
-        /* calibrate spectrum, FIXME: do in spc_obs? */
-        cpl_vector_divide(cpl_bivector_get_y(std), cpl_bivector_get_y(model));
-        cpl_vector_divide(cpl_bivector_get_y(stde), cpl_bivector_get_y(model));
-        cpl_bivector_delete(model);
-    }
-    skip_if(0);
+    n_std_ext = cpl_frame_get_nextensions(frm);
+    std_fn = cpl_frame_get_filename(frm);
+    // cpl_msg_info(cpl_func, "standard %s has %d extensions", std_fn, n_std_ext);
 
     for (int i = 0; i < irplib_framelist_get_size(objtab); i++) {
         char buffer[300];
         cpl_frame * ofrm =
             cpl_frame_duplicate(irplib_framelist_get_const(objtab, i));
+        sprintf(buffer, "visir_calibrated_%03d.fits", i + 1);
+        /* Keep track of whether the first extension has been written for this new file */
+        int is_saved = 0;
+
+        const int next = cpl_frame_get_nextensions(ofrm);
+        const char * fn = cpl_frame_get_filename(ofrm);
+        /* Ensure that the standard and the object have the same number of extensions */
+        cpl_ensure_code(next == n_std_ext, CPL_ERROR_ILLEGAL_INPUT);
+        // cpl_msg_info(cpl_func, "object %s has %d extensions", fn, next);
+
         cpl_frame * sfrm = cpl_frame_duplicate(frm);
         cpl_frameset * usedframes = cpl_frameset_new();
         cpl_frame_set_group(sfrm, CPL_FRAME_GROUP_CALIB);
@@ -568,39 +577,64 @@ get_spec_std(cpl_frameset            * framelist,
         cpl_frameset_insert(usedframes, sfrm);
         cpl_frameset_insert(usedframes, ofrm);
 
-        cpl_table * obj = calibrate_frame(ofrm, std, stde);
-        sprintf(buffer, "visir_calibrated_%03d.fits", i + 1);
-        irplib_dfs_save_table(framelist, parlist, usedframes, obj,
-                                      NULL, RECIPE_STRING, procatg, NULL,/* todo*/
-                                      NULL, visir_pipe_id, buffer);
+        cpl_propertylist * phu = cpl_propertylist_load(fn, 0);
 
-        /* add the image and extraction weight too (see visir_spc_obs_save) */
-        if (cpl_frame_get_nextensions(ofrm) == 3) {
-            cpl_propertylist * plist =
-                cpl_propertylist_load(cpl_frame_get_filename(ofrm), 2);
-            cpl_image * img = cpl_image_load(cpl_frame_get_filename(ofrm),
-                                             CPL_TYPE_UNSPECIFIED, 0, 2);
-            cpl_image_save(img, buffer, CPL_TYPE_UNSPECIFIED, plist, CPL_IO_EXTEND);
-            cpl_image_delete(img);
-            cpl_propertylist_delete(plist);
-            plist = cpl_propertylist_load(cpl_frame_get_filename(ofrm), 2);
-            img = cpl_image_load(cpl_frame_get_filename(ofrm),
-                                 CPL_TYPE_UNSPECIFIED, 0, 2);
-            cpl_image_save(img, buffer, CPL_TYPE_UNSPECIFIED, plist, CPL_IO_EXTEND);
-            cpl_image_delete(img);
+        /* Iterate over all the available extensions */
+        for (int j=1; j<=next; j++) {
+            /* Load the FITS header to determine what this extension is */
+            cpl_propertylist * plist = cpl_propertylist_load(fn, j);
+            const char * xt = cpl_propertylist_get_string(plist, "XTENSION");
+            cpl_msg_info(cpl_func, "object %s extension %d is %s", fn, j, xt);
+            // Remove/rename keywords as required
+            visir_dfs_update_header(plist);
+            if (!strcmp(xt, "BINTABLE")) {
+                /* A table extension will contain the extracted spectrum */
+                /* Load the associated std spectrum */
+                cpl_bivector * model = visir_bivector_load_fits(std_fn, "WLEN",
+                                                                "STD_STAR_MODEL", j);
+                std = visir_bivector_load_fits(std_fn, "WLEN", "SPC_EXTRACTED", j);
+                stde = visir_bivector_load_fits(std_fn, "WLEN", "SPC_ERROR", j);
+                /* calibrate std spectrum, FIXME: do in spc_obs? */
+                cpl_vector_divide(cpl_bivector_get_y(std), cpl_bivector_get_y(model));
+                cpl_vector_divide(cpl_bivector_get_y(stde), cpl_bivector_get_y(model));
+                cpl_bivector_delete(model);
+
+                /* calibrate object spectrum */
+                cpl_table * obj = calibrate_frame(ofrm, j, std, stde);
+
+                /* Save this as the first extension if required, otherwise extend
+                 * the existing file */
+                if (!is_saved) {
+                    irplib_dfs_save_table(framelist, parlist, usedframes, obj,
+                                          plist, RECIPE_STRING, procatg, phu,
+                                          NULL, visir_pipe_id, buffer);
+                    is_saved = 1;
+                } else {
+                    cpl_table_save(obj, NULL, plist, buffer, CPL_IO_EXTEND);
+                }
+                cpl_bivector_delete(std);
+                cpl_bivector_delete(stde);
+
+            } else if (!strcmp(xt, "IMAGE")) {
+                /* Copy across IMAGE extensions unchanged.
+                 * They are the trimmed image and associated extraction weights */
+                cpl_image * img = cpl_image_load(fn, CPL_TYPE_UNSPECIFIED, 0, j);
+                cpl_image_save(img, buffer, CPL_TYPE_UNSPECIFIED, plist, CPL_IO_EXTEND);
+                cpl_image_delete(img);
+            } else {
+                /* Give a warning for unknown extensions - should not happen */
+                cpl_msg_warning(cpl_func, "Cannot process %s extension %d of unknown type %s", fn, j, xt);
+            }
             cpl_propertylist_delete(plist);
         }
+        cpl_propertylist_delete(phu);
 
         cpl_frameset_delete(usedframes);
-        cpl_table_delete(obj);
         skip_if(0);
     }
 
     end_skip;
 
-    cpl_bivector_delete(std);
-    cpl_bivector_delete(stde);
-
     return cpl_error_get_code();
 }
 
