@@ -301,6 +301,8 @@ cpl_error_code visir_util_convert_weight_one(cpl_frameset * framelist,
         cpl_propertylist_delete(plist);
         plist = cpl_propertylist_load_regexp(filename, iext, CPL_DFS_PRO_CATG,
                                              CPL_TRUE);
+        /* Update the headers before saving */
+        visir_dfs_update_header(plist);
 
         skip_if(plist == NULL);
 
@@ -618,8 +620,8 @@ cpl_error_code visir_util_convert_weight_one(cpl_frameset * framelist,
         }
     }
 
-    FOR_EACH_FRAMESET_C(frame, products) {
-        cpl_frame * copy = cpl_frame_duplicate(frame);
+    FOR_EACH_FRAMESET_C(frm, products) {
+        cpl_frame * copy = cpl_frame_duplicate(frm);
         cpl_error_code error = cpl_frameset_insert(framelist, copy);
 
         if (error) break;
