@@ -1023,6 +1023,8 @@ save_images(cx_list * imgs, const cpl_propertylist * mplist,
         sprintf(buffer, RECIPE_STRING"_%03d_%s"CPL_DFS_FITS,
                 iframe+1, type2string[pl->type]);
 
+        /* Update the headers before saving */
+        visir_dfs_update_header(pl->plist);
         cpl_image_save(pl->img, buffer, save_type,
                        pl->plist, CPL_IO_EXTEND);
         nbytes_save += cpl_image_get_size_x(pl->img) *
