@@ -282,8 +282,9 @@ cpl_error_code visir_util_join_one(cpl_frameset * framelist,
     skip_if(img == NULL);
 
     if (qcframes) {
-        frame = irplib_framelist_get_const(qcframes, qcshared ? 0 : i);
-        filename = cpl_frame_get_filename(frame);
+        const cpl_frame * qcframe =
+            irplib_framelist_get_const(qcframes, qcshared ? 0 : i);
+        filename = cpl_frame_get_filename(qcframe);
         qc_plist = cpl_propertylist_load_regexp(filename, 0,
                                 "ESO QC |BUNIT|ESO DRS CATG", CPL_FALSE);
         skip_if (qc_plist == NULL);
