@@ -349,7 +349,6 @@ run_swarp_coadd(cpl_frame * imgfrm, cpl_frame * errfrm,
         sem_close(sem_resamp);
 
         for (int k = 0; k < l; k++) {
-            int status;
             pid_t r = waitpid(lpids[k], &status, 0);
             if (r == -1 || !WIFEXITED(status) || WEXITSTATUS(status))
                 _exit(WEXITSTATUS(status));
@@ -429,15 +428,17 @@ generate_coaddition_header(const cx_list * imglist, const char * config, const c
         int ret;
         cpl_propertylist * plist =
             cpl_propertylist_load(cpl_frame_get_filename(frm), 0);
-        int cd11ok = plist && cpl_propertylist_has(plist, "CD1_1") &&
-            cpl_propertylist_get_double(plist, "CD1_1") != 0.;
-        int cd22ok = plist && cpl_propertylist_has(plist, "CD2_2") &&
-            cpl_propertylist_get_double(plist, "CD2_2") != 0.;
+        cpl_errorstate cleanstate = cpl_errorstate_get();
+        cpl_boolean invalid =
+            (cpl_propertylist_get_double(plist, "CD1_1") == 0. &&
+             cpl_propertylist_get_double(plist, "CD1_2") == 0.) ||
+            (cpl_propertylist_get_double(plist, "CD2_1") == 0. &&
+             cpl_propertylist_get_double(plist, "CD2_2") == 0.);
+        invalid = invalid || (cpl_error_get_code() != CPL_ERROR_NONE);
+        cpl_errorstate_set(cleanstate);
         cpl_propertylist_delete(plist);
-        error_if (!cd11ok, CPL_ERROR_ILLEGAL_INPUT,
-                  "CD1_1 WCS key missing or zero");
-        error_if (!cd22ok, CPL_ERROR_ILLEGAL_INPUT,
-                  "CD2_2 WCS key missing or zero");
+        error_if (invalid, CPL_ERROR_ILLEGAL_INPUT,
+                  "CDX_Y WCS key missing or zero");
 
         cpl_msg_info(cpl_func, "%s",  cpl_frame_get_filename(frm));
         ret = fprintf(data, "%s\n", cpl_frame_get_filename(frm));
@@ -872,6 +873,8 @@ static int visir_util_run_swarp(cpl_frameset            * framelist,
     cx_list * errlist = cx_list_new();
 
     skip_if(check_swarp());
+    /* only reading single extension files, no cache needed */
+    cpl_fits_set_mode(CPL_FITS_STOP_CACHING);
 
     const cpl_boolean output_all =
         irplib_parameterlist_get_bool(parlist, PACKAGE,
@@ -889,7 +892,7 @@ static int visir_util_run_swarp(cpl_frameset            * framelist,
         extra = "";
 
     if (nmax_procs <= 0) {
-        nmax_procs = visir_get_num_threads(CPL_FALSE);
+        nmax_procs = visir_get_num_threads(CPL_TRUE);
     }
 
     error_if(visir_str_par_is_empty(config), CPL_ERROR_FILE_NOT_FOUND,
