@@ -274,15 +274,15 @@ vimglist_append(visir_imglist * a, visir_imglist * b)
 }
 
 static visir_imglist *
-load_images(cpl_frame * frame, const cpl_mask * bpm)
+load_images(cpl_frame * frame, const cpl_mask * bpm, const char * keyword)
 {
+    const char * kword = keyword ? keyword : "ESO DRS CUMOFFSET.";
     const int next = cpl_frame_get_nextensions(frame);
     const char * filename  = cpl_frame_get_filename(frame);
     cpl_image * img = NULL;
     visir_imglist * res = visir_imglist_new(next, NULL);
-    cpl_propertylist * plist = cpl_propertylist_load_regexp(filename, 0,
-                                                "ESO DRS CUMOFFSET.",
-                                                CPL_FALSE);
+    cpl_propertylist * plist = cpl_propertylist_load_regexp(filename, 0, kword,
+                                                            CPL_FALSE);
     for (int iext = 0; iext < next + 1; iext++) {
         cpl_errorstate prestate = cpl_errorstate_get();
 
@@ -323,10 +323,12 @@ overscan_correct(cpl_image * img)
 {
     const cpl_size nx = cpl_image_get_size_x(img);
     const cpl_size ny = cpl_image_get_size_y(img);
+
+    /* FIXME: remove hardcoding, maybe use window keys from fits */
+    cpl_image * top = cpl_image_extract(img, 1, ny - 7, nx, ny);
+    cpl_image * bot = cpl_image_extract(img, 1, 7, nx, 13);
+
     for (cpl_size x = 1; x < nx + 1; x++) {
-        /* FIXME: remove hardcoding, maybe use window keys from fits */
-        cpl_image * top = cpl_image_extract(img, 1, ny - 7, nx, ny);
-        cpl_image * bot = cpl_image_extract(img, 1, 7, nx, 13);
         cpl_vector * t = cpl_vector_new_from_image_column(top, x);
         cpl_vector * b = cpl_vector_new_from_image_column(bot, x);
         double topmed = cpl_vector_get_median(t);
@@ -341,10 +343,11 @@ overscan_correct(cpl_image * img)
         }
         cpl_vector_delete(t);
         cpl_vector_delete(b);
-        cpl_image_delete(top);
-        cpl_image_delete(bot);
     }
 
+    cpl_image_delete(top);
+    cpl_image_delete(bot);
+
     return cpl_error_get_code();
 }
 
@@ -353,13 +356,12 @@ static cpl_error_code
 handle_images(visir_imglist * list, const cpl_image * base,
               cpl_size xl, cpl_size yl, cpl_size xh, cpl_size yh,
               double phi, double ksi, double eps, double delta,
-              const visir_data_type dtype,
-              const visir_spc_resol resol)
+              const visir_data_type dtype)
 {
     const cpl_size n = visir_imglist_get_size(list);
     const cpl_size nx = cpl_image_get_size_x(visir_imglist_get_img(list, 0));
     const cpl_size ny = cpl_image_get_size_y(visir_imglist_get_img(list, 0));
-    error_if(xh >  nx || yh > ny, CPL_ERROR_ILLEGAL_INPUT,
+    error_if(xh > nx || yh > ny, CPL_ERROR_ILLEGAL_INPUT,
              "Sky region %d/%d larger than image %d/%d", (int)xh, (int)yh,
              (int)nx, (int)ny);
 
@@ -377,14 +379,12 @@ handle_images(visir_imglist * list, const cpl_image * base,
         }
         else {
             overscan_correct(img);
-            if (resol == VISIR_SPC_R_LRP) {
-                cpl_propertylist * plist = visir_imglist_get_data(list, i);
-                double dx = cpl_propertylist_get_double(plist,
-                                                        VISIR_DRS_CUMOFFSETX);
-                double dy = cpl_propertylist_get_double(plist,
-                                                        VISIR_DRS_CUMOFFSETY);
-                visir_spc_det_warp(&img, 1, -dx, -dy, phi, ksi, eps, delta);
-            }
+            cpl_propertylist * plist = visir_imglist_get_data(list, i);
+            double dx = cpl_propertylist_get_double(plist,
+                                VISIR_DRS_CUMOFFSETX);
+            double dy = cpl_propertylist_get_double(plist,
+                                VISIR_DRS_CUMOFFSETY);
+            visir_spc_det_warp(&img, 1, -dx, -dy, phi, ksi, eps, delta);
         }
     }
 
@@ -528,6 +528,11 @@ static void update_exectime(const cpl_frame * frm, double * t_min_obsstart,
     cpl_propertylist_delete(plist);
 }
 
+static void vimglist_delete(visir_imglist * list)
+{
+    visir_imglist_delete(list, (visir_free)&cpl_propertylist_delete);
+}
+
 /*----------------------------------------------------------------------------*/
 /**
   @brief    The recipe data reduction part is implemented here 
@@ -669,9 +674,9 @@ static int visir_util_undistort(cpl_frameset            * framelist,
         bpm = cpl_mask_load(badpix, 0, 0);
         skip_if (bpm == NULL);
     }
+
     double t_min_obsstart = 1e300;
     double t_max_filewrite = 0;
-    
     if (rawframes_a) {
         cx_list * on_frames = sort_framelist(rawframes_a, "^("
                                              VISIR_UTIL_REPACK_A_ON_PROCATG
@@ -681,14 +686,14 @@ static int visir_util_undistort(cpl_frameset            * framelist,
                                               ")$");
         FOR_EACH_T(cpl_frame * frm, on_frames) {
             update_exectime(frm, &t_min_obsstart, &t_max_filewrite);
-            vimglist_append(aon, load_images(frm, bpm));
+            vimglist_append(aon, load_images(frm, bpm, NULL));
             cpl_frame_set_group(frm, CPL_FRAME_GROUP_RAW);
             cpl_frameset_insert(usedframes, cpl_frame_duplicate(frm));
         }
         cx_list_destroy(on_frames, (visir_free)cpl_frame_delete);
         FOR_EACH_T(cpl_frame * frm, off_frames) {
             update_exectime(frm, &t_min_obsstart, &t_max_filewrite);
-            vimglist_append(aoff, load_images(frm, bpm));
+            vimglist_append(aoff, load_images(frm, bpm, NULL));
             cpl_frame_set_group(frm, CPL_FRAME_GROUP_RAW);
             cpl_frameset_insert(usedframes, cpl_frame_duplicate(frm));
         }
@@ -698,9 +703,9 @@ static int visir_util_undistort(cpl_frameset            * framelist,
         if (visir_data_is_aqu(data_type))
             overscan_correct(base);
         skip_if(handle_images(aon, base, xl, yl, xh, yh,
-                              phi, ksi, eps, delta, data_type, resol));
+                              phi, ksi, eps, delta, data_type));
         skip_if(handle_images(aoff, base, xl, yl, xh, yh,
-                              phi, ksi, eps, delta, data_type, resol));
+                              phi, ksi, eps, delta, data_type));
     }
     if (rawframes_b){
         cx_list * on_frames = sort_framelist(rawframes_b, "^("
@@ -711,14 +716,14 @@ static int visir_util_undistort(cpl_frameset            * framelist,
                                               ")$");
         FOR_EACH_T(cpl_frame * frm, on_frames) {
             update_exectime(frm, &t_min_obsstart, &t_max_filewrite);
-            vimglist_append(bon, load_images(frm, bpm));
+            vimglist_append(bon, load_images(frm, bpm, NULL));
             cpl_frame_set_group(frm, CPL_FRAME_GROUP_RAW);
             cpl_frameset_insert(usedframes, cpl_frame_duplicate(frm));
         }
         cx_list_destroy(on_frames, (visir_free)cpl_frame_delete);
         FOR_EACH_T(cpl_frame * frm, off_frames) {
             update_exectime(frm, &t_min_obsstart, &t_max_filewrite);
-            vimglist_append(boff, load_images(frm, bpm));
+            vimglist_append(boff, load_images(frm, bpm, NULL));
             cpl_frame_set_group(frm, CPL_FRAME_GROUP_RAW);
             cpl_frameset_insert(usedframes, cpl_frame_duplicate(frm));
         }
@@ -731,9 +736,9 @@ static int visir_util_undistort(cpl_frameset            * framelist,
         }
 
         skip_if(handle_images(bon, base, xl, yl, xh, yh,
-                              phi, ksi, eps, delta, data_type, resol));
+                              phi, ksi, eps, delta, data_type));
         skip_if(handle_images(boff, base, xl, yl, xh, yh,
-                              phi, ksi, eps, delta, data_type, resol));
+                              phi, ksi, eps, delta, data_type));
     }
 
     if (bkgcorrect && rawframes_a && rawframes_b) {
@@ -751,7 +756,8 @@ static int visir_util_undistort(cpl_frameset            * framelist,
 
         {
             cpl_image * img = cpl_imagelist_collapse_create(laon);
-            cpl_image * flipped = visir_spc_flip(img, wlen, resol, data_type);
+            cpl_image * flipped = visir_spc_flip(img, wlen, resol, data_type,
+                                                 NULL);
             cpl_image_delete(img);
             img = flipped;
 
@@ -761,7 +767,7 @@ static int visir_util_undistort(cpl_frameset            * framelist,
         cpl_propertylist_append_double(plist, "ESO QC EXECTIME",
                            (t_max_filewrite - t_min_obsstart) * 24 * 3600);
         save_images(l, framelist, usedframes, plist, parlist);
-        visir_imglist_delete(l, (visir_free)cpl_propertylist_delete);
+        vimglist_delete(l);
         skip_if(0);
     }
     else {
@@ -790,7 +796,8 @@ static int visir_util_undistort(cpl_frameset            * framelist,
         }
 
         skip_if(visir_spc_det_warp(&base, 1, 0., 0.,  phi, ksi, eps, delta));
-        cpl_image * flipped = visir_spc_flip(base, wlen, resol, data_type);
+        cpl_image * flipped = visir_spc_flip(base, wlen, resol, data_type,
+                                             NULL);
         cpl_image_delete(base);
         base = flipped;
     }
@@ -809,10 +816,10 @@ static int visir_util_undistort(cpl_frameset            * framelist,
     cpl_image_delete(imbpm);
     cpl_mask_delete(bpm);
     cpl_image_delete(base);
-    visir_imglist_delete(aon, (visir_free)&cpl_propertylist_delete);
-    visir_imglist_delete(aoff, (visir_free)&cpl_propertylist_delete);
-    visir_imglist_delete(bon, (visir_free)&cpl_propertylist_delete);
-    visir_imglist_delete(boff, (visir_free)&cpl_propertylist_delete);
+    vimglist_delete(aon);
+    vimglist_delete(aoff);
+    vimglist_delete(bon);
+    vimglist_delete(boff);
     cpl_frameset_delete(usedframes);
 
     return cpl_error_get_code();
