@@ -4,7 +4,11 @@ from __future__ import absolute_import
 from __future__ import print_function
 from fitsrpcserver import Server, deser_array
 from visir_utils import Future
-import xmlrpclib
+try:
+    import xmlrpclib
+except ImportError:
+    from xmlrpc import client as xmlrpclib
+    
 import pickle
 from threading import Lock
 try:
@@ -24,7 +28,11 @@ except ImportError:
     threading.cpu_count = lambda : 1
     threading.Queue = lambda : Queue.Queue()
     mp = threading
-
+try:
+  basestring
+except NameError:
+  basestring = str
+  
 def run_server(port, q):
     try:
         s = Server(port=port)
