@@ -1,7 +1,14 @@
 from __future__ import absolute_import
-from SimpleXMLRPCServer import SimpleXMLRPCServer
-from SimpleXMLRPCServer import SimpleXMLRPCRequestHandler
-import xmlrpclib
+try:
+    from SimpleXMLRPCServer import SimpleXMLRPCServer
+    from SimpleXMLRPCServer import SimpleXMLRPCRequestHandler
+    import xmlrpclib
+    from cStringIO import StringIO as myIO
+except ImportError:
+    from xmlrpc import client as xmlrpclib
+    from xmlrpc.server import SimpleXMLRPCServer
+    from xmlrpc.server import SimpleXMLRPCRequestHandler
+    from io import BytesIO as myIO
 import pickle
 try:
     import pyfits
@@ -11,18 +18,18 @@ except ImportError:
 pyfits.ENABLE_RECORD_VALUED_KEYWORD_CARDS = False
 
 import numpy
-import cStringIO
+
 def ser_array(x):
     if x is None:
         return x
-    f = cStringIO.StringIO()
+    f = myIO()
     numpy.lib.format.write_array(f, x)
     return xmlrpclib.Binary(f.getvalue())
 
 def deser_array(s):
     if s == None:
         return None
-    f = cStringIO.StringIO(s.data)
+    f = myIO(s.data)
     return numpy.lib.format.read_array(f)
 
 
