@@ -126,16 +126,17 @@ class DataPlotterManager:
             self.plt['av'] = ImagePlot(figure, figure.add_subplot(334))
             self.plt['img'] = ImagePlot(figure, figure.add_subplot(335))
             self.plt['tmpl'] = ImagePlot(figure, figure.add_subplot(336))
-            self.plt['shifts'] = ImagePlot(figure, figure.add_subplot(313))
-            self.plt['stats'] = LinePlot(figure, figure.add_axes([0.30, 0.70,
-                                                                 0.675, 0.25]))
-            self.rax = figure.add_axes([0.02, 0.75, 0.20, 0.13])
+            self.plt['shifts'] = ImagePlot(figure,
+                    figure.add_axes([0.1, 0.075, 0.875, 0.225]))
+            self.plt['stats'] = LinePlot(figure,
+                    figure.add_axes([0.30, 0.725, 0.675, 0.225]))
+            self.rax = figure.add_axes([0.02, 0.80, 0.20, 0.13])
             self.rax.tooltip = 'Select statistics to plot'
             self.statskeys = sorted(self.stats.keys())
             self.statslabels = [self.stats[x]['label'] for x in self.statskeys]
             self.rad = RadioButtons(self.rax, self.statslabels,
                                     active=self.statskeys.index(self.dflt_stat))
-            self.bax = figure.add_axes([0.08, 0.65, 0.13, 0.05])
+            self.bax = figure.add_axes([0.08, 0.725, 0.13, 0.05])
             self.beamselect = Button(self.bax, 'Select beams', color='gray')
             self.beamselect.on_clicked(self.select_beams)
         else:
@@ -494,6 +495,7 @@ class DataPlotterManager:
                             tooltip_scatter, scatx, scaty)
         # add a histogram for many points
         if (len(scatx) > 50):
+            self.plt['shifts'].ax.grid(False)
             self.plt['shifts'].data, binsx, binsy, aximg = \
                 self.plt['shifts'].ax.hist2d(scatx, scaty, bins=25, alpha=0.75)
             aximg.set_cmap('gray')
