@@ -13,7 +13,55 @@ from reflexlib import VisirParameter
 from reflex import RecipeParameter
 import numpy as np
 import os
-from wx.lib.mixins.listctrl import CheckListCtrlMixin
+
+def CheckWxVersion(minver):
+    return list(map(int, wx.version().split(' ')[0].split('.'))) >= minver
+
+class ListCtrl(wx.ListCtrl):
+    """Wrapper around wx.ListCtrl to have more control
+    over the widget on different platforms/wxpython versions"""
+    def __init__(self, *args, **kwargs):
+        wx.ListCtrl.__init__(self, *args, **kwargs)
+
+    def InsertItem(self, index, label, imageIndex=-1):
+        if CheckWxVersion([4, 0, 0]):
+            return wx.ListCtrl.InsertItem(self, index=index, label=label, imageIndex=imageIndex)
+        else:
+            return wx.ListCtrl.InsertStringItem(self, index=index, label=label, imageIndex=0)#imageIndex)
+
+    def SetItem(self, index, column, label, imageId=-1):
+        if CheckWxVersion([4, 0, 0]):
+            return wx.ListCtrl.SetItem(self, index=index, column=column, label=label, imageId=imageId)
+        else:
+            return wx.ListCtrl.SetStringItem(self, index=index, col=column, label=label, imageId=imageId)
+
+    def CheckItem(self, item, check=True):
+        """Uses either deprecated listmix.CheckListCtrlMixin
+        or new checkbox implementation in wx.ListCtrl since 4.1.0"""
+        if hasattr(self, 'HasCheckBoxes'):
+            wx.ListCtrl.CheckItem(self, item, check)
+        else:
+            super(ListCtrl, self).CheckItem(item, check)
+
+    def IsItemChecked(self, item):
+        if hasattr(self, 'HasCheckBoxes'):
+            return wx.ListCtrl.IsItemChecked(self, item)
+        else:
+            return super(ListCtrl, self).IsChecked(item)
+
+if CheckWxVersion([4, 1, 0]):
+    class CheckListCtrlMixin():
+        """This class pretends to be deprecated CheckListCtrlMixin mixin and
+        only enables checkboxes in new versions of ListCtrl"""
+        def __init__(self):
+            self.EnableCheckBoxes(True)
+            self.AssignImageList(wx.ImageList(16, 16), wx.IMAGE_LIST_SMALL)
+else:
+    import wx.lib.mixins.listctrl as listmix
+    class CheckListCtrlMixin(listmix.CheckListCtrlMixin):
+        """Wrapper for deprecated mixin"""
+        def __init__(self):
+            listmix.CheckListCtrlMixin.__init__(self)
 
 
 def add_dialog_buttons(parent, on_help=None):
@@ -61,13 +109,13 @@ class PlotDialog(wx.Dialog):
 
         sizer.Add(plotPanel, 1, wx.EXPAND)
         sizer.Add(add_dialog_buttons(self), 0, wx.EXPAND)
-        sizer.AddSpacer((0, 3), 0, wx.EXPAND, 5)
+        sizer.Add((0, 0))
         self.SetSizer(sizer)
 
 
-class CheckListCtrl(wx.ListCtrl, CheckListCtrlMixin):
+class CheckListCtrl(ListCtrl, CheckListCtrlMixin):
     def __init__(self, parent, id, pos, size):
-        wx.ListCtrl.__init__(self, parent, id, pos, size, style=wx.LC_REPORT)
+        ListCtrl.__init__(self, parent, id, pos, size, style=wx.LC_REPORT)
         CheckListCtrlMixin.__init__(self)
 
 
@@ -110,7 +158,7 @@ class BeamDialog(wx.Dialog):
 
         sizer.Add(mainsizer, 1, wx.EXPAND)
         sizer.Add(add_dialog_buttons(self, on_help=self.on_help), 0, wx.EXPAND)
-        sizer.AddSpacer((0, 3), 0, wx.EXPAND, 5)
+        sizer.Add((0, 0))
         self.SetSizer(sizer)
 
         self.data = data
@@ -173,16 +221,16 @@ A checked box represents a positive beam and an unchecked box a negative beam.
         if not add and ind >= 0:
             self.beamBox.DeleteItem(ind)
         else:
-            idx = self.beamBox.InsertStringItem(sys.maxsize, '')
+            idx = self.beamBox.InsertItem(sys.maxsize, '')
             sign = self.check_sign(*data, d=self.data)
             if sign == 'pos':
                 self.beamBox.CheckItem(idx)
-            self.beamBox.SetStringItem(idx, 1, st)
+            self.beamBox.SetItem(idx, 1, st)
 
     def get_selections(self):
         res = []
         for idx in range(self.beamBox.GetItemCount()):
-            sign = 'pos' if self.beamBox.IsChecked(idx)else 'neg'
+            sign = 'pos' if self.beamBox.IsItemChecked(idx) else 'neg'
             pos = map(int, self.beamBox.GetItem(idx, 1).GetText().split(','))
             res.append((sign, pos))
         return res
@@ -209,7 +257,10 @@ class ParamWidget:
         self.set_value(param.value)
         self.default = self.get_value()
         if param.description:
-            self.paramCtrl.SetToolTipString(param.description)
+            try:
+                self.paramCtrl.SetToolTip(param.description)
+            except:
+                self.paramCtrl.SetToolTipString(param.description)
 
     def get_value(self):
         try:
@@ -361,14 +412,17 @@ class ReflexBaseGui(wx.App):
             self.filesList.Append([file.category, file.name])
             self.filesList.SetColumnWidth(0, wx.LIST_AUTOSIZE)
             self.filesList.SetColumnWidth(1, wx.LIST_AUTOSIZE)
-            self.filesList.SetToolTipString("List of files that have been an"
-                "input of this window. If you click on a particular file, you"
-                " can double click or press Ctrl-C to copy the full path name"
-                " onto the clipboard.")
+            mys = "List of files that have been an input of this window. If "\
+                "you click on a particular file, you can double click or "\
+                "press Ctrl-C to copy the full path name onto the clipboard."
+            try:
+                self.filesList.SetToolTip(mys)
+            except:
+                self.filesList.SetToolTipString(mys)
 
     def setupParameters(self):
         parTab = xrc.XRCCTRL(self.frame, 'parameterPanel')
-        parTab.SetMinSize((170, 340))
+        parTab.SetMinSize((170, 380))
         parGrid = wx.FlexGridSizer(cols=2, vgap=0, hgap=0)
         parGrid.AddGrowableCol(1)
         parTab.SetSizer(parGrid, 1)
@@ -419,6 +473,8 @@ class ReflexBaseGui(wx.App):
 
         if hasattr(self, 'set_next_iteration_enable'):
             self.io.outputs.set_enable = self.set_next_iteration_enable
+        else:
+            self.io.outputs.set_enable = 'true'
 
         self.frame.Close(True)
 
@@ -451,6 +507,8 @@ class ReflexBaseGui(wx.App):
         self.io.outputs.out_sof_loop = self.io.inputs.in_sof_rec_orig
         if hasattr(self, 'set_next_iteration_enable'):
             self.io.outputs.set_enable = self.set_next_iteration_enable
+        else:
+            self.io.outputs.set_enable = 'true'
 
         self.frame.Close(True)
 
