@@ -13,8 +13,8 @@ class SquareSelector(RectangleSelector):
         self.sq_onselect = onselect
         RectangleSelector.__init__(self, ax=ax, onselect=lambda x, y: True,
                                    useblit=useblit, rectprops=rectprops,
-                                   minspanx=None, minspany=None,
-                                   spancoords='pixels', drawtype='box')
+                                   spancoords='pixels', drawtype='box',
+                                   interactive=True)
         self.selections = []
         self.dflt_size = dflt_size
         self.minspan = minspan
