@@ -30,8 +30,9 @@
 #ifdef HAVE_CONFIG_H
 #include	"config.h"
 #endif
-#ifndef _POSIX_SOURCE
-#define _POSIX_SOURCE /* for strtok_r */
+
+#ifndef _POSIX_C_SOURCE
+#define _POSIX_C_SOURCE 200112L /* for strtok_r */
 #endif
 
 #ifdef HAVE_MATHIMF_H
