@@ -273,4 +273,43 @@ static const char * visir_dfs_find_tag_from_dpr(const char * catg,
 
 }
 
-
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Update header prior to saving
+ * @param  plist               property list to update
+ *
+ * This function updates the given cpl_propertylist by translating
+ * RADECSYS to RADESYS and removing HDRVER.
+ */
+/*----------------------------------------------------------------------------*/
+void visir_dfs_update_header(cpl_propertylist* plist)
+{
+    const char *radecsys_hdr = "RADECSYS";
+    const char *radesys_hdr = "RADESYS";
+    const char *hdrver_hdr = "HDRVER";
+    const char *func = "update_header";
+    char *radec_str = NULL;
+    char *comment_str = NULL;
+    if (plist) {
+        // Remove HDRVER
+        cpl_propertylist_erase(plist, hdrver_hdr);
+        // Translate RADECSYS to RADESYS.
+        radec_str = cpl_strdup(cpl_propertylist_get_string(plist, radecsys_hdr));
+        comment_str = cpl_strdup(cpl_propertylist_get_comment(plist, radecsys_hdr));
+        cpl_propertylist_erase(plist, radecsys_hdr);
+        cpl_propertylist_update_string(plist, radesys_hdr, radec_str);
+        cpl_propertylist_set_comment(plist, radesys_hdr, comment_str);
+        if (cpl_error_get_code() != CPL_ERROR_NONE) {
+          /* Only give a warning if the header exists but there was a problem
+           * in translating it */
+          if (radec_str) {
+              cpl_msg_warning(func, "Error in updating header: %s",
+                  cpl_error_get_message());
+          }
+        }
+        cpl_free(radec_str);
+        cpl_free(comment_str);
+        // Don't want any errors to propagate up from here
+        cpl_error_reset();
+    }
+}
