@@ -32,7 +32,9 @@
                                    Includes
  -----------------------------------------------------------------------------*/
 
+#include "sbrm.h"
 #include <cpl.h>
+#include <cxlist.h> /* for cx_list */
 
 #include "irplib_framelist.h"
 
@@ -83,6 +85,38 @@ typedef enum {
     VISIR_DATA_AQU_INT,
 } visir_data_type;
 
+typedef enum {
+    VISIR_EXTRACT_METHOD_UNKNOWN = 0,
+    VISIR_EXTRACT_METHOD_APERTURE = 'A',
+    VISIR_EXTRACT_METHOD_OPTIMAL = 'O',
+} visir_extract_t;
+
+typedef enum {
+    VISIR_SKY_METHOD_UNKNOWN = 0,
+    VISIR_SKY_METHOD_AVERAGE = 'A',
+    VISIR_SKY_METHOD_LINFIT = 'F',
+    VISIR_SKY_METHOD_MEDIAN = 'M',
+} visir_sky_t;
+
+typedef struct { int l, r; } visir_aplimits;
+typedef struct {
+    const size_t nlimits;
+    int ident;
+    visir_extract_t extract_method;
+    visir_sky_t sky_method;
+    visir_aplimits limits[];  // c99's "flexible array member"
+} visir_apdefs;
+#define visir_apdefs_delete cpl_free
+#define visir_apdefs_new(...) \
+    SBRM_VALLOC(visir_apdefs, visir_aplimits, __VA_ARGS__)
+
+typedef cx_list visir_aplist;  // a list of visir_apdefs
+void visir_aplist_destroy(visir_aplist * list);
+#define visir_aplist_delete cx_list_delete
+#define visir_aplist_new cx_list_new
+#define visir_aplist_push_back cx_list_push_back
+#define visir_aplist_size cx_list_size
+
 static inline cpl_boolean
 visir_data_is_aqu(const visir_data_type dtype)
 {
@@ -124,6 +158,11 @@ cpl_image ** visir_img_recombine(const char *, const cpl_parameterlist *,
 cpl_imagelist * visir_load_imagelist(const irplib_framelist *, int,
                                      cpl_boolean);
 cpl_imagelist * visir_load_hcycle(const irplib_framelist *, int);
+
+visir_aplist * visir_aplist_new_from_file(const char *);
+visir_apdefs * visir_apdefs_new_from_line(char *, int);
+char * visir_apdefs_dump(const visir_apdefs *);
+
 cpl_error_code visir_image_reject_hot(cpl_image *, const char *);
 
 cpl_imagelist * visir_imagelist_load_last(const irplib_framelist *);
