@@ -242,7 +242,7 @@ cpl_error_code visir_parameter_set(cpl_parameterlist * self,
                         "Subtract the median from the spectral column before "
                         "extracting the wavelength. This is required when "
                         "the skylines do not correctly cancel due to gratting "
-                        "oscillations", FALSE, "bkgcorrect");
+                        "oscillations", TRUE, "bkgcorrect");
 
     /* --plot */
     VISIR_PARAMETER_SET(VISIR_PARAM_PLOT, "plot", CPL_TYPE_INT,
@@ -463,6 +463,33 @@ cpl_error_code visir_parameter_set(cpl_parameterlist * self,
                         "dispersion mode a (small) negative number may be used "
                         "(pixel)", 0, "rr");
 
+    /* --apfile */
+    VISIR_PARAMETER_SET(VISIR_PARAM_APERT_FILE, "apfile", CPL_TYPE_STRING,
+                        "An optional ASCII file specification of the aperture "
+                        "definitions to use during spectral extraction. "
+                        "Each line must contain either 3 fields for optimal "
+                        "extraction, or an even number of fields greater than 5 "
+                        "for aperture extraction. For optimal extraction, the "
+                        "1st field should be 'O', and for aperture extraction "
+                        "it should be 'A'. In both cases the next pair of fields "
+                        "indicate the left & right edges of the source aperture "
+                        "in pixel coordinates. For aperture extraction, fields "
+                        "after the 3rd define the sky apertures coordinates, "
+                        "with the 4th field indicating the method used to "
+                        "determine the sky background [one of 'A' (average), "
+                        "'F' (linear fit), or 'M' (median)] followed by at "
+                        "least one pair of pixel coordinates representing the "
+                        "left & right edge of a sky aperture. You may supply "
+                        "more sky apertures by supplying additional pixel "
+                        "coordinate pairs after the first.  Multiple lines "
+                        "targeting the same order are allowed.",
+                        VISIR_STR_PAR_EMPTY, "apfile");
+
+    /* --ro_noise */
+    VISIR_PARAMETER_SET(VISIR_PARAM_RONOISE, "ron", CPL_TYPE_DOUBLE,
+                        "Readout noise of the detector",
+                        14.5, "ro_noise");
+
     /* --eccmax */
     VISIR_PARAMETER_SET(VISIR_PARAM_ECCMAX, "eccmax", CPL_TYPE_DOUBLE,
                        "The maximum eccentricity allowed in the combination "
@@ -474,6 +501,42 @@ cpl_error_code visir_parameter_set(cpl_parameterlist * self,
                         "the side length will have eccentricity 0",
                         0.25, "eccmax");
 
+    /* --ox_sigma */
+    VISIR_PARAMETER_SET(VISIR_PARAM_OXSIGMA, "optex_sigma", CPL_TYPE_DOUBLE,
+                        "Sigma to use for clipping in optimal extraction",
+                        5.0, "ox_sigma");
+
+    /* --ox_niters */
+    VISIR_PARAMETER_SET(VISIR_PARAM_OXNITER, "optex_niters", CPL_TYPE_INT,
+                        "Number of optimal extraction iterations to perform",
+                        2, "ox_niters");
+
+    /* --ox_smooth */
+    VISIR_PARAMETER_SET(VISIR_PARAM_OXSMOOTH, "optex_smooth", CPL_TYPE_INT,
+                        "Width of smoothing window to use along spectral "
+                        "dimension during optimal extraction. A median filter "
+                        "is used.",
+                        31, "ox_smooth");
+
+    /* --gain */
+    VISIR_PARAMETER_SET(VISIR_PARAM_GAIN, "gain", CPL_TYPE_DOUBLE,
+                        "Detector gain",
+                        0.75, "gain");
+
+    /* --ox_kernel */
+    VISIR_PARAMETER_SET(VISIR_PARAM_OXKERNEL, "optex_kernel", CPL_TYPE_INT,
+                        "Size of square smoothing kernel, in pixels, to apply "
+                        "to science frame before optimal extraction (ignored "
+                        "during aperture extraction). A median filter is used.",
+                        3, "ox_kernel");
+
+    /* --respcal */
+    VISIR_PARAMETER_SET(VISIR_PARAM_RESPCAL, "respcal", CPL_TYPE_STRING,
+                        "An optional path to a FITS file containing a 1-D "
+                        "fringe model to be divided into the 1-D extracted "
+                        "spectra in order to remove the fringes.",
+                        VISIR_STR_PAR_EMPTY, "respcal");
+
     cpl_free(context);
 
     cpl_ensure_code(!cpl_error_get_code(), cpl_error_get_code());
@@ -581,6 +644,15 @@ int visir_parameterlist_get_int(const cpl_parameterlist * self,
     /* --rr */
     VISIR_PARAMETER_GET_INT(VISIR_PARAM_REJRIGHT, "reject_right");
 
+    /* --ox_niters */
+    VISIR_PARAMETER_GET_INT(VISIR_PARAM_OXNITER, "optex_niters");
+
+    /* --ox_smooth */
+    VISIR_PARAMETER_GET_INT(VISIR_PARAM_OXSMOOTH, "optex_smooth");
+
+    /* --ox_kernel */
+    VISIR_PARAMETER_GET_INT(VISIR_PARAM_OXKERNEL, "optex_kernel");
+
 
     cpl_ensure(bitmask == 0, CPL_ERROR_UNSUPPORTED_MODE, 0);
     cpl_ensure(nbits == 1,   CPL_ERROR_ILLEGAL_INPUT, 0);
@@ -625,6 +697,9 @@ double visir_parameterlist_get_double(const cpl_parameterlist * self,
     /* --hori_arc */
     VISIR_PARAMETER_GET_DOUBLE(VISIR_PARAM_HORIARC, "delta");
 
+    /* --ro_noise */
+    VISIR_PARAMETER_GET_DOUBLE(VISIR_PARAM_RONOISE, "ron");
+
     /* --jy_val */
     VISIR_PARAMETER_GET_DOUBLE(VISIR_PARAM_JYVAL, "jy_val");
 
@@ -652,6 +727,12 @@ double visir_parameterlist_get_double(const cpl_parameterlist * self,
     /* --eccmax */
     VISIR_PARAMETER_GET_DOUBLE(VISIR_PARAM_ECCMAX, "eccmax");
 
+    /* --ox_sigma */
+    VISIR_PARAMETER_GET_DOUBLE(VISIR_PARAM_OXSIGMA, "optex_sigma");
+
+    /* --gain */
+    VISIR_PARAMETER_GET_DOUBLE(VISIR_PARAM_GAIN, "gain");
+
     cpl_ensure(bitmask == 0, CPL_ERROR_UNSUPPORTED_MODE, 0.0);
     cpl_ensure(nbits == 1,   CPL_ERROR_ILLEGAL_INPUT, 0.0);
 
@@ -709,6 +790,12 @@ const char * visir_parameterlist_get_string(const cpl_parameterlist * self,
     /* --combine */
     VISIR_PARAMETER_GET_STRING(VISIR_PARAM_COMBINE, "comb_meth");
 
+    /* --apfile */
+    VISIR_PARAMETER_GET_STRING(VISIR_PARAM_APERT_FILE, "apfile");
+
+    /* --apfile */
+    VISIR_PARAMETER_GET_STRING(VISIR_PARAM_RESPCAL, "respcal");
+
     cpl_ensure(bitmask == 0, CPL_ERROR_UNSUPPORTED_MODE, NULL);
     cpl_ensure(nbits == 1,   CPL_ERROR_ILLEGAL_INPUT, NULL);
 
