@@ -42,44 +42,52 @@
 
 /* The available recipe parameters */
 /* The value 1 is unused, which makes the (mis)use of logical or detectable */
-#define VISIR_PARAM_NODPOS   ((visir_parameter) 1 <<  1)
-#define VISIR_PARAM_AUTOBPM  ((visir_parameter) 1 <<  2)
-#define VISIR_PARAM_GLITCH   ((visir_parameter) 1 <<  3)
-#define VISIR_PARAM_PURGE    ((visir_parameter) 1 <<  4)
-#define VISIR_PARAM_UNION    ((visir_parameter) 1 <<  5)
-#define VISIR_PARAM_REJECT   ((visir_parameter) 1 <<  6)
-#define VISIR_PARAM_PLOT     ((visir_parameter) 1 <<  7)
-#define VISIR_PARAM_SLITSKEW ((visir_parameter) 1 <<  8)
-#define VISIR_PARAM_SPECSKEW ((visir_parameter) 1 <<  9)
-#define VISIR_PARAM_VERTARC  ((visir_parameter) 1 << 10)
-#define VISIR_PARAM_HORIARC  ((visir_parameter) 1 << 11)
-#define VISIR_PARAM_ORDEROFF ((visir_parameter) 1 << 12)
-#define VISIR_PARAM_OFFSETS  ((visir_parameter) 1 << 13)
-#define VISIR_PARAM_OBJECTS  ((visir_parameter) 1 << 14)
-#define VISIR_PARAM_REFINE   ((visir_parameter) 1 << 15)
-#define VISIR_PARAM_XCORR    ((visir_parameter) 1 << 16)
-#define VISIR_PARAM_JYVAL    ((visir_parameter) 1 << 17)
-#define VISIR_PARAM_RADII    ((visir_parameter) 1 << 18)
-#define VISIR_PARAM_LOWLIM   ((visir_parameter) 1 << 19)
-#define VISIR_PARAM_HIGHLIM  ((visir_parameter) 1 << 20)
-#define VISIR_PARAM_FIXCOMBI ((visir_parameter) 1 << 21)
-#define VISIR_PARAM_EMIS_TOL ((visir_parameter) 1 << 22)
-#define VISIR_PARAM_ZERODIST ((visir_parameter) 1 << 23)
-#define VISIR_PARAM_QEFF     ((visir_parameter) 1 << 24)
-#define VISIR_PARAM_REJBORD  ((visir_parameter) 1 << 25)
-#define VISIR_PARAM_HOT_LIM  ((visir_parameter) 1 << 26)
-#define VISIR_PARAM_COLD_LIM ((visir_parameter) 1 << 27)
-#define VISIR_PARAM_DEV_LIM  ((visir_parameter) 1 << 28)
-#define VISIR_PARAM_NSAMPLES ((visir_parameter) 1 << 29)
-#define VISIR_PARAM_HALFSIZE ((visir_parameter) 1 << 30)
-#define VISIR_PARAM_COMBINE  ((visir_parameter) 1 << 31)
-#define VISIR_PARAM_STRIPNON ((visir_parameter) 1 << 32)
-#define VISIR_PARAM_STRIPITE ((visir_parameter) 1 << 33)
-#define VISIR_PARAM_STRIPMOR ((visir_parameter) 1 << 34)
-#define VISIR_PARAM_REJLEFT  ((visir_parameter) 1 << 35)
-#define VISIR_PARAM_REJRIGHT ((visir_parameter) 1 << 36)
-#define VISIR_PARAM_ECCMAX   ((visir_parameter) 1 << 37)
+#define VISIR_PARAM_NODPOS      ((visir_parameter) 1 <<  1)
+#define VISIR_PARAM_AUTOBPM     ((visir_parameter) 1 <<  2)
+#define VISIR_PARAM_GLITCH      ((visir_parameter) 1 <<  3)
+#define VISIR_PARAM_PURGE       ((visir_parameter) 1 <<  4)
+#define VISIR_PARAM_UNION       ((visir_parameter) 1 <<  5)
+#define VISIR_PARAM_REJECT      ((visir_parameter) 1 <<  6)
+#define VISIR_PARAM_PLOT        ((visir_parameter) 1 <<  7)
+#define VISIR_PARAM_SLITSKEW    ((visir_parameter) 1 <<  8)
+#define VISIR_PARAM_SPECSKEW    ((visir_parameter) 1 <<  9)
+#define VISIR_PARAM_VERTARC     ((visir_parameter) 1 << 10)
+#define VISIR_PARAM_HORIARC     ((visir_parameter) 1 << 11)
+#define VISIR_PARAM_ORDEROFF    ((visir_parameter) 1 << 12)
+#define VISIR_PARAM_OFFSETS     ((visir_parameter) 1 << 13)
+#define VISIR_PARAM_OBJECTS     ((visir_parameter) 1 << 14)
+#define VISIR_PARAM_REFINE      ((visir_parameter) 1 << 15)
+#define VISIR_PARAM_XCORR       ((visir_parameter) 1 << 16)
+#define VISIR_PARAM_JYVAL       ((visir_parameter) 1 << 17)
+#define VISIR_PARAM_RADII       ((visir_parameter) 1 << 18)
+#define VISIR_PARAM_LOWLIM      ((visir_parameter) 1 << 19)
+#define VISIR_PARAM_HIGHLIM     ((visir_parameter) 1 << 20)
+#define VISIR_PARAM_FIXCOMBI    ((visir_parameter) 1 << 21)
+#define VISIR_PARAM_EMIS_TOL    ((visir_parameter) 1 << 22)
+#define VISIR_PARAM_ZERODIST    ((visir_parameter) 1 << 23)
+#define VISIR_PARAM_QEFF        ((visir_parameter) 1 << 24)
+#define VISIR_PARAM_REJBORD     ((visir_parameter) 1 << 25)
+#define VISIR_PARAM_HOT_LIM     ((visir_parameter) 1 << 26)
+#define VISIR_PARAM_COLD_LIM    ((visir_parameter) 1 << 27)
+#define VISIR_PARAM_DEV_LIM     ((visir_parameter) 1 << 28)
+#define VISIR_PARAM_NSAMPLES    ((visir_parameter) 1 << 29)
+#define VISIR_PARAM_HALFSIZE    ((visir_parameter) 1 << 30)
+#define VISIR_PARAM_COMBINE     ((visir_parameter) 1 << 31)
+#define VISIR_PARAM_STRIPNON    ((visir_parameter) 1 << 32)
+#define VISIR_PARAM_STRIPITE    ((visir_parameter) 1 << 33)
+#define VISIR_PARAM_STRIPMOR    ((visir_parameter) 1 << 34)
+#define VISIR_PARAM_REJLEFT     ((visir_parameter) 1 << 35)
+#define VISIR_PARAM_REJRIGHT    ((visir_parameter) 1 << 36)
+#define VISIR_PARAM_ECCMAX      ((visir_parameter) 1 << 37)
 #define VISIR_PARAM_BKG_CORRECT ((visir_parameter) 1 << 38)
+#define VISIR_PARAM_APERT_FILE  ((visir_parameter) 1 << 39)
+#define VISIR_PARAM_RONOISE     ((visir_parameter) 1 << 40)
+#define VISIR_PARAM_GAIN        ((visir_parameter) 1 << 41)
+#define VISIR_PARAM_OXSIGMA     ((visir_parameter) 1 << 42)
+#define VISIR_PARAM_OXNITER     ((visir_parameter) 1 << 43)
+#define VISIR_PARAM_OXSMOOTH    ((visir_parameter) 1 << 44)
+#define VISIR_PARAM_OXKERNEL    ((visir_parameter) 1 << 45)
+#define VISIR_PARAM_RESPCAL     ((visir_parameter) 1 << 46)
 
 
 /*-----------------------------------------------------------------------------
