@@ -1,4 +1,4 @@
-/* $Id: visir_spc_distortion.c,v 1.45 2011/11/29 09:28:59 llundin Exp $
+/* $Id: visir_spc_distortion.c,v 1.50 2013-03-18 15:12:11 jtaylor Exp $
  *
  * This file is part of the VISIR Pipeline
  * Copyright (C) 2002,2003 European Southern Observatory
@@ -19,10 +19,10 @@
  */
 
 /*
- * $Author: llundin $
- * $Date: 2011/11/29 09:28:59 $
- * $Revision: 1.45 $
- * $Name: visir-3_5_1 $
+ * $Author: jtaylor $
+ * $Date: 2013-03-18 15:12:11 $
+ * $Revision: 1.50 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -53,7 +53,7 @@
 
 static cpl_error_code visir_spc_det_warp_xy(int, double, double, double, double,
                                             double, double, double, double,
-                                            double *, double*);
+                                            double, double, double *, double*);
 
 /*-----------------------------------------------------------------------------
                                    Functions code
@@ -103,6 +103,9 @@ cpl_error_code visir_spc_det_fix(cpl_image ** images, int nimages,
 
     skip_if (0);
 
+    /* FIXME: LRP mode has an as yet unparameterized distortion */
+    if (resol == VISIR_SPC_R_LRP) return CPL_ERROR_NONE;
+
     skip_if (images == NULL);
     skip_if (nimages <= 0);
 
@@ -139,7 +142,8 @@ cpl_error_code visir_spc_det_fix(cpl_image ** images, int nimages,
 
         visir_optmod ins_settings;
 
-        if (visir_spc_optmod_init(VISIR_SPC_R_HR, wlen, &ins_settings)) {
+        /* for a or b detection aqu or drs does not matter */
+        if (visir_spc_optmod_init(VISIR_SPC_R_HR, wlen, &ins_settings, 0)) {
             visir_error_set(CPL_ERROR_ILLEGAL_INPUT);
             skip_if(1);
         }
@@ -240,7 +244,7 @@ cpl_error_code visir_spc_det_fix(cpl_image ** images, int nimages,
     }
 
     /* Apply the distortion correction  */
-    skip_if (visir_spc_det_warp(images, nimages, phi, ksi, eps, delta));
+    skip_if (visir_spc_det_warp(images, nimages, 0., 0., phi, ksi, eps, delta));
 
     if (doplot > 1) visir_image_plot("", "t 'The first corrected image'",
                                      "", images[0]);
@@ -272,8 +276,9 @@ cpl_error_code visir_spc_det_fix(cpl_image ** images, int nimages,
  */
 /*----------------------------------------------------------------------------*/
 cpl_error_code visir_spc_det_warp(cpl_image ** images, int nimages,
-                                         double phi, double ksi,
-                                         double eps, double delta)
+                                  double xshift, double yshift,
+                                  double phi, double ksi,
+                                  double eps, double delta)
 {
 
 
@@ -281,7 +286,8 @@ cpl_error_code visir_spc_det_warp(cpl_image ** images, int nimages,
     const int tabsperpix = CPL_KERNEL_TABSPERPIX;
     const int nx = cpl_image_get_size_x(images[0]);
     const int ny = cpl_image_get_size_y(images[0]);
-    const cpl_boolean do_warp = phi != 0 || ksi != 0 || eps != 0 || delta != 0;
+    const cpl_boolean do_warp = phi != 0 || ksi != 0 ||
+        eps != 0 || delta != 0 || xshift != 0 || yshift != 0;
     int iu, iv;
     int iimage;
     int ipix;
@@ -317,7 +323,8 @@ cpl_error_code visir_spc_det_warp(cpl_image ** images, int nimages,
         for (ipix = 0, iv = 1; iv <= ny; iv++) {
             for (iu = 1; iu <= nx; iu++, ipix++) {
 
-                skip_if (visir_spc_det_warp_xy(1, nx, ny, iu, iv, phi, ksi, eps,
+                skip_if (visir_spc_det_warp_xy(1, nx, ny, iu, iv,
+                                               xshift, yshift, phi, ksi, eps,
                                                delta, &x, &y));
                 piu[ipix] = x;
                 piv[ipix] = y;
@@ -327,7 +334,7 @@ cpl_error_code visir_spc_det_warp(cpl_image ** images, int nimages,
     }
 
 #ifdef _OPENMP
-#pragma omp parallel for private(iimage, ipix, iv, iu, copy)
+#pragma omp parallel for private(iimage, ipix, iv, iu, copy) if (nimages > 1)
 #endif
     for (iimage = 0 ; iimage < nimages; iimage++) {
         cpl_image * image = images[iimage];
@@ -396,6 +403,7 @@ cpl_error_code visir_spc_det_warp(cpl_image ** images, int nimages,
                             preject = cpl_mask_get_data(rejected);
                         }
                         preject[ipix] = CPL_BINARY_1;
+                        px[ipix] = NAN;
                     } else {
                         /* The equivalent of at least 2 of the
                            nearest 4 pixels are good */
@@ -474,6 +482,8 @@ cpl_error_code visir_spc_det_warp(cpl_image ** images, int nimages,
   @param    ny     The detector size in the wavelength-direction [pixel]
   @param    x      The unwarped field-coordinate [pixel] (1..npix)
   @param    y      The unwarped wavelength-coordinate [pixel] (1..npix)
+  @param    xshift shift in x direction
+  @param    yshift shift in y direction
   @param    phi    The skew of slit [radian] (positive counter-clockwise)
   @param    ksi    The skew of spectrum [radian]  (positive counter-clockwise)
   @param    eps    The horizontal curvature [pixel] (positive downwards)
@@ -484,11 +494,13 @@ cpl_error_code visir_spc_det_warp(cpl_image ** images, int nimages,
 
   In case of the combined image, nx may be different from the detector size.
 
-  The warping has four elements:
-  1) A skew of the horizontal lines (phi)
-  2) A skew of the vertical lines (ksi)
-  3) Curvature of the horizontal lines (eps)
-  4) Curvature of the vertical lines (delta)
+  The warping has six elements:
+  1) A shift in x direction
+  2) A shift in y direction
+  3) A skew of the horizontal lines (phi)
+  4) A skew of the vertical lines (ksi)
+  5) Curvature of the horizontal lines (eps)
+  6) Curvature of the vertical lines (delta)
 
   The curvature is assumed to be a circle segment.
   The detector center is chosen as fix-point for the transformation.
@@ -500,10 +512,11 @@ cpl_error_code visir_spc_det_warp(cpl_image ** images, int nimages,
  */
 /*----------------------------------------------------------------------------*/
 static cpl_error_code visir_spc_det_warp_xy(int inv, double nx, double ny,
-                                     double x, double y,
-                                     double phi, double ksi,
-                                     double eps, double delta,
-                                     double *pu, double *pv)
+                                            double x, double y,
+                                            double xshift, double yshift,
+                                            double phi, double ksi,
+                                            double eps, double delta,
+                                            double *pu, double *pv)
 {
 
 
@@ -536,7 +549,7 @@ static cpl_error_code visir_spc_det_warp_xy(int inv, double nx, double ny,
 
         if (eps != 0) {
             /* Correct horizontal curvature */
-            const double R = ((ny/2)*(ny/2) + eps*eps) / fabs(2 * eps);
+            const double R = ((nx/2)*(nx/2) + eps*eps) / fabs(2 * eps);
 
             cpl_ensure_code(R >= x, CPL_ERROR_ILLEGAL_INPUT);
 
@@ -549,8 +562,14 @@ static cpl_error_code visir_spc_det_warp_xy(int inv, double nx, double ny,
         /* Skew into vertical lines */
         x -= y * tan(ksi);
 
+        x -= xshift;
+        y -= yshift;
+
     } else {
 
+        x += xshift;
+        y += yshift;
+
         /* Skew into vertical lines */
         x += y * tan(ksi);
 
@@ -582,6 +601,6 @@ static cpl_error_code visir_spc_det_warp_xy(int inv, double nx, double ny,
     *pu = x;
     *pv = y;
 
-    return cpl_error_get_code();
+    return CPL_ERROR_NONE;
 
 }
