@@ -59,7 +59,7 @@ static cpl_error_code visir_spc_sens_stat(const visir_spc_config *,
                                           double *, double *, double *,
                                           const cpl_table *);
 
-static cpl_error_code visir_spc_phot_qc(cpl_propertylist *,
+static cpl_error_code visir_spc_phot_qc(cpl_propertylist *, cpl_propertylist *,
                                         const char *, double, double, double,
                                         double, double);
 
@@ -94,7 +94,7 @@ static cpl_error_code visir_spc_phot_qc(cpl_propertylist *,
 /**
   @brief    Compute the sensitivity from an extracted spectrum
   @param    rawframes      List of input raw frames
-  @param    pconfig        The config struct
+  @param    cfg            The config struct
   @param    plist          The properties (DIT, NDIT etc.)
   @param    star_cat       The standard star catalog
   @param    pweight2d      2D weights image to be created or NULL on error
@@ -108,7 +108,7 @@ static cpl_error_code visir_spc_phot_qc(cpl_propertylist *,
 /*----------------------------------------------------------------------------*/
 cpl_error_code
 visir_spc_phot_sensit(const irplib_framelist * rawframes,
-                      const visir_spc_config * pconfig,
+                      const visir_spc_config * cfg,
                       const cpl_propertylist * plist,
                       const char   * star_cat,
                       cpl_image   ** pweight2d,
@@ -217,17 +217,17 @@ visir_spc_phot_sensit(const irplib_framelist * rawframes,
         }
     }
 
-    skip_if(visir_spc_sens_stat(pconfig, resol, &sens_median, &sens_mean,
+    skip_if(visir_spc_sens_stat(cfg, resol, &sens_median, &sens_mean,
                                 &sens_stdev, spc_table));
 
     /* This column is not part of the product */
     skip_if (cpl_table_erase_column(spc_table, "SPC_EMISSIVITY"));
 
-    skip_if (visir_spc_phot_qc(qclist, star_name, exptime, exectime,
+    skip_if (visir_spc_phot_qc(qclist, cfg->phu, star_name, exptime, exectime,
                                sens_median, sens_mean, sens_stdev));
 
     /* Plot the results */
-    if (pconfig->plot) {
+    if (cfg->plot) {
         visir_table_plot("", "t 'Extracted spectrum' w lines", "", spc_table,
                          "WLEN", "SPC_EXTRACTED");
         visir_table_plot("", "t 'Extracted spectrum error' w lines", "",
@@ -330,44 +330,41 @@ visir_spc_phot_sensit_from_image(cpl_image    ** combined,
                                pconfig->plot));
 
     /* Convert the combined image */
-    flipped = visir_spc_flip(*combined, wlen, resol, dtype);
+    bool rev;
+    flipped = visir_spc_flip(*combined, wlen, resol, dtype, &rev);
     skip_if (0);
     cpl_image_delete(*combined);
     *combined = flipped;
     flipped = NULL;
 
     /* Convert the half cycle image */
-    flipped = visir_spc_flip(imhcycle, wlen, resol, dtype);
+    flipped = visir_spc_flip(imhcycle, wlen, resol, dtype, NULL);
     skip_if (0);
     cpl_image_delete(imhcycle);
     imhcycle = flipped;
     flipped = NULL;
 
-    skip_if(visir_spc_extract_order(&order, &comorder,
-                                    *combined, imhcycle,
-                                    wlen, pconfig, do_ech,
-                                    visir_data_is_aqu(dtype)));
+    const int ncomb = visir_get_ncombine(rawframes);
+    skip_if (!ncomb);
 
-    if (do_ech) {
-        int icol1, icol2;
-        skip_if (visir_spc_echelle_limit(&icol1, &icol2, wlen,
-                                         pconfig->orderoffset,
-                                         1, cpl_image_get_size_y(*combined),
-                                         visir_data_is_aqu(dtype)));
-        skip_if(visir_qc_append_background(qclist, rawframes, icol1, icol2));
-    }
-    else
-        skip_if(visir_qc_append_background(qclist, rawframes, 0, 0));
+    int lcol = -1, rcol = -1;
+    skip_if(visir_spc_extract_order(&order, &comorder, &lcol, &rcol, *combined,
+                                    imhcycle, wlen, pconfig, do_ech,
+                                    visir_data_is_aqu(dtype)));
+    skip_if(visir_qc_append_background(qclist, rawframes, 
+                                       do_ech ? lcol : 0,
+                                       do_ech ? rcol : 0));
+
+    int const ident = -1;  // neg ident: use old extract alg
+    visir_apdefs * const aps = visir_apdefs_new(1, ident, 'O', 0);
+    aps->limits[0] = (visir_aplimits){ lcol, rcol };
 
     /* Extract the spectrum */
-    skip_if (visir_spc_extract_wcal(comorder,
-                                    order, wlen, slitw, temp, fwhm,
-                                    resol, pconfig->orderoffset,
-                                    spc_cal_lines, spc_cal_qeff,
-                                    &spc_table, pweight2d,
-                                    qclist,
-                                    pconfig->plot, CPL_FALSE,
-                                    visir_data_is_aqu(dtype)));
+    skip_if (visir_spc_extract_wcal(comorder, order, lcol, rcol, wlen, slitw,
+                                    temp, fwhm, resol, pconfig, spc_cal_lines,
+                                    spc_cal_qeff, visir_data_is_aqu(dtype), aps,
+                                    ncomb, rev, &spc_table, pweight2d, qclist));
+                                    
 
     visir_spc_phot_sensit(rawframes, pconfig, plist, star_cat, pweight2d,
                           qclist, spc_table, resol, dit_key);
@@ -754,7 +751,8 @@ static cpl_error_code visir_spc_sens_stat(const visir_spc_config * pconfig,
 /*----------------------------------------------------------------------------*/
 /**
   @brief    Append the spectro-phot QC parameters to the supplied list
-  @param    self        The list of properties to be extended
+  @param    qclist      The per-extension list of properties to be extended
+  @param    phu_qclist  The primary header list of properties to be extended
   @param    star_name   The name of the star, or NULL
   @param    exptime     The exposure time
   @param    exectime    The execution time
@@ -765,7 +763,8 @@ static cpl_error_code visir_spc_sens_stat(const visir_spc_config * pconfig,
 
  */
 /*----------------------------------------------------------------------------*/
-static cpl_error_code visir_spc_phot_qc(cpl_propertylist * self,
+static cpl_error_code visir_spc_phot_qc(cpl_propertylist * qclist,
+                                        cpl_propertylist * phu_qclist,
                                         const char * star_name,
                                         double exptime,
                                         double exectime,
@@ -774,18 +773,18 @@ static cpl_error_code visir_spc_phot_qc(cpl_propertylist * self,
                                         double sens_stdev)
 {
 
-    bug_if (cpl_propertylist_append_double(self, "ESO QC EXPTIME", exptime));
+    bug_if (cpl_propertylist_append_double(phu_qclist, "ESO QC EXPTIME", exptime));
     if (exectime > 0) {
-        bug_if (cpl_propertylist_append_double(self, "ESO QC EXECTIME",
+        bug_if (cpl_propertylist_append_double(phu_qclist, "ESO QC EXECTIME",
                                                exectime));
     }
-    bug_if (cpl_propertylist_append_double(self, "ESO QC SENS MEDIAN",
+    bug_if (cpl_propertylist_append_double(qclist, "ESO QC SENS MEDIAN",
                                            sens_median));
-    bug_if (cpl_propertylist_append_double(self, "ESO QC SENS MEAN", sens_mean));
-    bug_if (cpl_propertylist_append_double(self, "ESO QC SENS STDEV",
+    bug_if (cpl_propertylist_append_double(qclist, "ESO QC SENS MEAN", sens_mean));
+    bug_if (cpl_propertylist_append_double(qclist, "ESO QC SENS STDEV",
                                            sens_stdev));
     /* FIXME: Verify that this is the correct behaviour */
-    bug_if (cpl_propertylist_append_string(self, "ESO QC STARNAME",
+    bug_if (cpl_propertylist_append_string(phu_qclist, "ESO QC STARNAME",
                                            star_name ? star_name : ""));
 
     end_skip;
